"""
Python module generated from Java source file org.bukkit.plugin.Plugin

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import File
from java.io import InputStream
from org.bukkit import Server
from org.bukkit.command import TabExecutor
from org.bukkit.configuration.file import FileConfiguration
from org.bukkit.generator import BiomeProvider
from org.bukkit.generator import ChunkGenerator
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class Plugin(TabExecutor):
    """
    Represents a Plugin
    
    The use of PluginBase is recommended for actual Implementation
    """

    def getDataFolder(self) -> "File":
        """
        Returns the folder that the plugin data's files are located in. The
        folder may not yet exist.

        Returns
        - The folder
        """
        ...


    def getDescription(self) -> "PluginDescriptionFile":
        """
        Returns the plugin.yaml file containing the details for this plugin

        Returns
        - Contents of the plugin.yaml file
        """
        ...


    def getConfig(self) -> "FileConfiguration":
        """
        Gets a FileConfiguration for this plugin, read through
        "config.yml"
        
        If there is a default config.yml embedded in this plugin, it will be
        provided as a default for this Configuration.

        Returns
        - Plugin configuration
        """
        ...


    def getResource(self, filename: str) -> "InputStream":
        """
        Gets an embedded resource in this plugin

        Arguments
        - filename: Filename of the resource

        Returns
        - File if found, otherwise null
        """
        ...


    def saveConfig(self) -> None:
        """
        Saves the FileConfiguration retrievable by .getConfig().
        """
        ...


    def saveDefaultConfig(self) -> None:
        """
        Saves the raw contents of the default config.yml file to the location
        retrievable by .getConfig().
        
        This should fail silently if the config.yml already exists.
        """
        ...


    def saveResource(self, resourcePath: str, replace: bool) -> None:
        """
        Saves the raw contents of any resource embedded with a plugin's .jar
        file assuming it can be found using .getResource(String).
        
        The resource is saved into the plugin's data folder using the same
        hierarchy as the .jar file (subdirectories are preserved).

        Arguments
        - resourcePath: the embedded resource path to look for within the
            plugin's .jar file. (No preceding slash).
        - replace: if True, the embedded resource will overwrite the
            contents of an existing file.

        Raises
        - IllegalArgumentException: if the resource path is null, empty,
            or points to a nonexistent resource.
        """
        ...


    def reloadConfig(self) -> None:
        """
        Discards any data in .getConfig() and reloads from disk.
        """
        ...


    def getPluginLoader(self) -> "PluginLoader":
        """
        Gets the associated PluginLoader responsible for this plugin

        Returns
        - PluginLoader that controls this plugin
        """
        ...


    def getServer(self) -> "Server":
        """
        Returns the Server instance currently running this plugin

        Returns
        - Server running this plugin
        """
        ...


    def isEnabled(self) -> bool:
        """
        Returns a value indicating whether or not this plugin is currently
        enabled

        Returns
        - True if this plugin is enabled, otherwise False
        """
        ...


    def onDisable(self) -> None:
        """
        Called when this plugin is disabled
        """
        ...


    def onLoad(self) -> None:
        """
        Called after a plugin is loaded but before it has been enabled.
        
        When multiple plugins are loaded, the onLoad() for all plugins is
        called before any onEnable() is called.
        """
        ...


    def onEnable(self) -> None:
        """
        Called when this plugin is enabled
        """
        ...


    def isNaggable(self) -> bool:
        """
        Simple boolean if we can still nag to the logs about things

        Returns
        - boolean whether we can nag
        """
        ...


    def setNaggable(self, canNag: bool) -> None:
        """
        Set naggable state

        Arguments
        - canNag: is this plugin still naggable?
        """
        ...


    def getDefaultWorldGenerator(self, worldName: str, id: str) -> "ChunkGenerator":
        """
        Gets a ChunkGenerator for use in a default world, as specified
        in the server configuration

        Arguments
        - worldName: Name of the world that this will be applied to
        - id: Unique ID, if any, that was specified to indicate which
            generator was requested

        Returns
        - ChunkGenerator for use in the default world generation
        """
        ...


    def getDefaultBiomeProvider(self, worldName: str, id: str) -> "BiomeProvider":
        """
        Gets a BiomeProvider for use in a default world, as specified
        in the server configuration

        Arguments
        - worldName: Name of the world that this will be applied to
        - id: Unique ID, if any, that was specified to indicate which
            biome provider was requested

        Returns
        - BiomeProvider for use in the default world generation
        """
        ...


    def getLogger(self) -> "Logger":
        """
        Returns the plugin logger associated with this server's logger. The
        returned logger automatically tags all log messages with the plugin's
        name.

        Returns
        - Logger associated with this plugin
        """
        ...


    def getName(self) -> str:
        """
        Returns the name of the plugin.
        
        This should return the bare name of the plugin and should be used for
        comparison.

        Returns
        - name of the plugin
        """
        ...



"""
Python module generated from Java source file org.bukkit.util.io.BukkitObjectInputStream

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import InputStream
from java.io import ObjectInputStream
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import ConfigurationSerialization
from org.bukkit.util.io import *
from typing import Any, Callable, Iterable, Tuple


class BukkitObjectInputStream(ObjectInputStream):
    """
    This class is designed to be used in conjunction with the ConfigurationSerializable API. It translates objects back to their
    original implementation after being serialized by BukkitObjectInputStream.
    
    Behavior of implementations extending this class is not guaranteed across
    future versions.
    """

    def __init__(self, in: "InputStream"):
        """
        Object input stream decoration constructor.

        Arguments
        - in: the input stream to wrap

        Raises
        - IOException: if an I/O error occurs while reading stream header

        See
        - ObjectInputStream.ObjectInputStream(InputStream)
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.block.MoistureChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class MoistureChangeEvent(BlockEvent, Cancellable):
    """
    Called when the moisture level of a soil block changes.
    """

    def __init__(self, block: "Block", newState: "BlockState"):
        ...


    def getNewState(self) -> "BlockState":
        """
        Gets the new state of the affected block.

        Returns
        - new block state
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.Difficulty

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Maps
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Difficulty(Enum):
    """
    Represents the various difficulty levels that are available.
    """

    PEACEFUL = (0)
    """
    Players regain health over time, hostile mobs don't spawn, the hunger
    bar does not deplete.
    """
    EASY = (1)
    """
    Hostile mobs spawn, enemies deal less damage than on normal difficulty,
    the hunger bar does deplete and starving deals up to 5 hearts of
    damage. (Default value)
    """
    NORMAL = (2)
    """
    Hostile mobs spawn, enemies deal normal amounts of damage, the hunger
    bar does deplete and starving deals up to 9.5 hearts of damage.
    """
    HARD = (3)
    """
    Hostile mobs spawn, enemies deal greater damage than on normal
    difficulty, the hunger bar does deplete and starving can kill players.
    """


    def getValue(self) -> int:
        """
        Gets the difficulty value associated with this Difficulty.

        Returns
        - An integer value of this difficulty

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getByValue(value: int) -> "Difficulty":
        """
        Gets the Difficulty represented by the specified value

        Arguments
        - value: Value to check

        Returns
        - Associative Difficulty with the given value, or null if
            it doesn't exist

        Deprecated
        - Magic value
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.Callable

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class Callable:
    """
    A task that returns a result and may throw an exception.
    Implementors define a single method with no arguments called
    `call`.
    
    The `Callable` interface is similar to java.lang.Runnable, in that both are designed for classes whose
    instances are potentially executed by another thread.  A
    `Runnable`, however, does not return a result and cannot
    throw a checked exception.
    
    The Executors class contains utility methods to
    convert from other common forms to `Callable` classes.
    
    Type `<V>`: the result type of method `call`

    Author(s)
    - Doug Lea

    See
    - Executor

    Since
    - 1.5
    """

    def call(self) -> "V":
        """
        Computes a result, or throws an exception if unable to do so.

        Returns
        - computed result

        Raises
        - Exception: if unable to compute a result
        """
        ...



from .AccessController import AccessController
from .PrivilegedAction import PrivilegedAction
from .PrivilegedActionException import PrivilegedActionException
from .PrivilegedExceptionAction import PrivilegedExceptionAction
from .AccessControlException import AccessControlException
from .MessageDigest import MessageDigest
from .NoSuchAlgorithmException import NoSuchAlgorithmException
from .InvalidKeyException import InvalidKeyException
from .Key import Key
from .CodeSigner import CodeSigner
from .CodeSource import CodeSource


"""
Python module generated from Java source file com.google.common.net.UrlEscapers

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.escape import Escaper
from com.google.common.net import *
from typing import Any, Callable, Iterable, Tuple


class UrlEscapers:
    """
    `Escaper` instances suitable for strings to be included in particular sections of URLs.
    
    If the resulting URLs are inserted into an HTML or XML document, they will require additional
    escaping with com.google.common.html.HtmlEscapers or com.google.common.xml.XmlEscapers.

    Author(s)
    - Chris Povirk

    Since
    - 15.0
    """

    @staticmethod
    def urlFormParameterEscaper() -> "Escaper":
        """
        Returns an Escaper instance that escapes strings so they can be safely included in <a
        href="https://url.spec.whatwg.org/#application-x-www-form-urlencoded-percent-encode-set">URL
        form parameter names and values</a>. Escaping is performed with the UTF-8 character encoding.
        The caller is responsible for <a
        href="https://html.spec.whatwg.org/multipage/form-control-infrastructure.html#multipart-form-data">replacing
        any unpaired carriage return or line feed characters with a CR+LF pair</a> on any non-file
        inputs before escaping them with this escaper.
        
        When escaping a String, the following rules apply:
        
        
          - The alphanumeric characters "a" through "z", "A" through "Z" and "0" through "9" remain
              the same.
          - The special characters ".", "-", "*", and "_" remain the same.
          - The space character " " is converted into a plus sign "+".
          - All other characters are converted into one or more bytes using UTF-8 encoding and each
              byte is then represented by the 3-character string "%XY", where "XY" is the two-digit,
              uppercase, hexadecimal representation of the byte value.
        
        
        This escaper is suitable for escaping parameter names and values even when <a
        href="https://www.w3.org/TR/html401/appendix/notes.html#h-B.2.2">using the non-standard
        semicolon</a>, rather than the ampersand, as a parameter delimiter. Nevertheless, we recommend
        using the ampersand unless you must interoperate with systems that require semicolons.
        
        **Note:** Unlike other escapers, URL escapers produce <a
        href="https://url.spec.whatwg.org/#percent-encode">uppercase</a> hexadecimal sequences.
        """
        ...


    @staticmethod
    def urlPathSegmentEscaper() -> "Escaper":
        """
        Returns an Escaper instance that escapes strings so they can be safely included in <a
        href="https://url.spec.whatwg.org/#syntax-url-path-segment">URL path segments</a>. The returned
        escaper escapes all non-ASCII characters, even though <a
        href="https://url.spec.whatwg.org/#url-code-points">many of these are accepted in modern
        URLs</a>. (<a href="https://url.spec.whatwg.org/#path-state">If the escaper were to leave these
        characters unescaped, they would be escaped by the consumer at parse time, anyway.</a>)
        Additionally, the escaper escapes the slash character ("/"). While slashes are acceptable in
        URL paths, they are considered by the specification to be separators between "path segments."
        This implies that, if you wish for your path to contain slashes, you must escape each segment
        separately and then join them.
        
        When escaping a String, the following rules apply:
        
        
          - The alphanumeric characters "a" through "z", "A" through "Z" and "0" through "9" remain
              the same.
          - The unreserved characters ".", "-", "~", and "_" remain the same.
          - The general delimiters "@" and ":" remain the same.
          - The subdelimiters "!", "$", "&amp;", "'", "(", ")", "*", "+", ",", ";", and "=" remain
              the same.
          - The space character " " is converted into %20.
          - All other characters are converted into one or more bytes using UTF-8 encoding and each
              byte is then represented by the 3-character string "%XY", where "XY" is the two-digit,
              uppercase, hexadecimal representation of the byte value.
        
        
        **Note:** Unlike other escapers, URL escapers produce <a
        href="https://url.spec.whatwg.org/#percent-encode">uppercase</a> hexadecimal sequences.
        """
        ...


    @staticmethod
    def urlFragmentEscaper() -> "Escaper":
        """
        Returns an Escaper instance that escapes strings so they can be safely included in a <a
        href="https://url.spec.whatwg.org/#concept-url-fragment">URL fragment</a>. The returned escaper
        escapes all non-ASCII characters.
        
        When escaping a String, the following rules apply:
        
        
          - The alphanumeric characters "a" through "z", "A" through "Z" and "0" through "9" remain
              the same.
          - The unreserved characters ".", "-", "~", and "_" remain the same.
          - The general delimiters "@" and ":" remain the same.
          - The subdelimiters "!", "$", "&amp;", "'", "(", ")", "*", "+", ",", ";", and "=" remain
              the same.
          - The space character " " is converted into %20.
          - Fragments allow unescaped "/" and "?", so they remain the same.
          - All other characters are converted into one or more bytes using UTF-8 encoding and each
              byte is then represented by the 3-character string "%XY", where "XY" is the two-digit,
              uppercase, hexadecimal representation of the byte value.
        
        
        **Note:** Unlike other escapers, URL escapers produce <a
        href="https://url.spec.whatwg.org/#percent-encode">uppercase</a> hexadecimal sequences.
        """
        ...



"""
Python module generated from Java source file org.bukkit.command.defaults.HelpCommand

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Joiner
from com.google.common.base import Preconditions
from com.google.common.collect import ImmutableList
from java.util import Arrays
from org.bukkit import Bukkit
from org.bukkit import ChatColor
from org.bukkit.command import CommandSender
from org.bukkit.command import ConsoleCommandSender
from org.bukkit.command.defaults import *
from org.bukkit.help import HelpMap
from org.bukkit.help import HelpTopic
from org.bukkit.help import HelpTopicComparator
from org.bukkit.help import IndexHelpTopic
from org.bukkit.util import ChatPaginator
from typing import Any, Callable, Iterable, Tuple


class HelpCommand(BukkitCommand):

    def __init__(self):
        ...


    def execute(self, sender: "CommandSender", currentAlias: str, args: list[str]) -> bool:
        ...


    def tabComplete(self, sender: "CommandSender", alias: str, args: list[str]) -> list[str]:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.events.NodeEvent

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.events import *
from typing import Any, Callable, Iterable, Tuple


class NodeEvent(Event):
    """
    Base class for all events that mark the beginning of a node.
    """

    def __init__(self, anchor: str, startMark: "Mark", endMark: "Mark"):
        ...


    def getAnchor(self) -> str:
        """
        Node anchor by which this node might later be referenced by a AliasEvent.
        
        Note that AliasEvents are by it self `NodeEvent`s and use this property to
        indicate the referenced anchor.

        Returns
        - Anchor of this node or `null` if no anchor is defined.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Salmon

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Salmon(Fish):
    """
    Represents a salmon fish.
    """

    def getVariant(self) -> "Variant":
        """
        Get the variant of this salmon.

        Returns
        - salmon variant
        """
        ...


    def setVariant(self, variant: "Variant") -> None:
        """
        Set the variant of this salmon.

        Arguments
        - variant: salmon variant
        """
        ...


    class Variant(Enum):
        """
        Represents the variant of a salmon - ie its size.
        """

        SMALL = 0
        """
        Small salmon.
        """
        MEDIUM = 1
        """
        Default salmon.
        """
        LARGE = 2
        """
        Large salmon.
        """



"""
Python module generated from Java source file org.bukkit.event.player.PlayerEditBookEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit import Bukkit
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory.meta import BookMeta
from typing import Any, Callable, Iterable, Tuple


class PlayerEditBookEvent(PlayerEvent, Cancellable):
    """
    Called when a player edits or signs a book and quill item. If the event is
    cancelled, no changes are made to the BookMeta
    """

    def __init__(self, who: "Player", slot: int, previousBookMeta: "BookMeta", newBookMeta: "BookMeta", isSigning: bool):
        ...


    def getPreviousBookMeta(self) -> "BookMeta":
        """
        Gets the book meta currently on the book.
        
        Note: this is a copy of the book meta. You cannot use this object to
        change the existing book meta.

        Returns
        - the book meta currently on the book
        """
        ...


    def getNewBookMeta(self) -> "BookMeta":
        """
        Gets the book meta that the player is attempting to add to the book.
        
        Note: this is a copy of the proposed new book meta. Use .setNewBookMeta(BookMeta) to change what will actually be added to the
        book.

        Returns
        - the book meta that the player is attempting to add
        """
        ...


    def getSlot(self) -> int:
        """
        Gets the inventory slot number for the book item that triggered this
        event.
        
        This is a slot number on the player's hotbar in the range 0-8, or -1 for
        off hand.

        Returns
        - the inventory slot number that the book item occupies

        Deprecated
        - books may be signed from off hand
        """
        ...


    def setNewBookMeta(self, newBookMeta: "BookMeta") -> None:
        """
        Sets the book meta that will actually be added to the book.

        Arguments
        - newBookMeta: new book meta

        Raises
        - IllegalArgumentException: if the new book meta is null
        """
        ...


    def isSigning(self) -> bool:
        """
        Gets whether or not the book is being signed. If a book is signed the
        Material changes from BOOK_AND_QUILL to WRITTEN_BOOK.

        Returns
        - True if the book is being signed
        """
        ...


    def setSigning(self, signing: bool) -> None:
        """
        Sets whether or not the book is being signed. If a book is signed the
        Material changes from BOOK_AND_QUILL to WRITTEN_BOOK.

        Arguments
        - signing: whether or not the book is being signed.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...



"""
Python module generated from Java source file com.google.common.annotations.GwtCompatible

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import *
from typing import Any, Callable, Iterable, Tuple


class GwtCompatible:
    """
    The presence of this annotation on a type indicates that the type may be used with the <a
    href="http://code.google.com/webtoolkit/">Google Web Toolkit</a> (GWT). When applied to a method,
    the return type of the method is GWT compatible. It's useful to indicate that an instance created
    by factory methods has a GWT serializable type. In the following example,
    
    ```
    @GwtCompatible
    class Lists {
      ...
      @GwtCompatible(serializable = True)
      static <E> List<E> newArrayList(E... elements) {
        ...
      }
    }
    ```
    
    The return value of `Lists.newArrayList(E[])` has GWT serializable type. It is also
    useful in specifying contracts of interface methods. In the following example,
    
    ```
    @GwtCompatible
    interface ListFactory {
      ...
      @GwtCompatible(serializable = True)
      <E> List<E> newArrayList(E... elements);
    }
    ```
    
    The `newArrayList(E[])` method of all implementations of `ListFactory` is expected
    to return a value with a GWT serializable type.
    
    Note that a `GwtCompatible` type may have some GwtIncompatible methods.

    Author(s)
    - Hayward Chan
    """

    def serializable(self) -> bool:
        """
        When `True`, the annotated type or the type of the method return value is GWT
        serializable.

        See
        - <a href=
            "http://code.google.com/webtoolkit/doc/latest/DevGuideServerCommunication.html.DevGuideSerializableTypes">
            Documentation about GWT serialization</a>
        """
        return False


    def emulated(self) -> bool:
        """
        When `True`, the annotated type is emulated in GWT. The emulated source (also known as
        super-source) is different from the implementation used by the JVM.

        See
        - <a href=
            "http://code.google.com/webtoolkit/doc/latest/DevGuideOrganizingProjects.html.DevGuideModules">
            Documentation about GWT emulated source</a>
        """
        return False



"""
Python module generated from Java source file org.bukkit.event.entity.EntityDamageByEntityEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Function
from org.bukkit.damage import DamageSource
from org.bukkit.damage import DamageType
from org.bukkit.entity import Entity
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityDamageByEntityEvent(EntityDamageEvent):
    """
    Called when an entity is damaged by an entity
    """

    def __init__(self, damager: "Entity", damagee: "Entity", cause: "DamageCause", damage: float):
        ...


    def __init__(self, damager: "Entity", damagee: "Entity", cause: "DamageCause", damageSource: "DamageSource", damage: float):
        ...


    def __init__(self, damager: "Entity", damagee: "Entity", cause: "DamageCause", modifiers: dict["DamageModifier", "Double"], modifierFunctions: dict["DamageModifier", "Function"["Double", "Double"]]):
        ...


    def __init__(self, damager: "Entity", damagee: "Entity", cause: "DamageCause", damageSource: "DamageSource", modifiers: dict["DamageModifier", "Double"], modifierFunctions: dict["DamageModifier", "Function"["Double", "Double"]]):
        ...


    def getDamager(self) -> "Entity":
        """
        Returns the entity that damaged the defender.

        Returns
        - Entity that damaged the defender.
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ServiceManagerBridge

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import ImmutableMultimap
from com.google.common.util.concurrent import *
from com.google.common.util.concurrent.Service import State
from typing import Any, Callable, Iterable, Tuple


class ServiceManagerBridge:
    """
    Superinterface of ServiceManager to introduce a bridge method for `servicesByState()`, to ensure binary compatibility with older Guava versions that specified
    `servicesByState()` to return `ImmutableMultimap`.
    """

    def servicesByState(self) -> "ImmutableMultimap"["State", "Service"]:
        ...



"""
Python module generated from Java source file org.bukkit.entity.LivingEntity

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import UUID
from org.bukkit import FluidCollisionMode
from org.bukkit import Location
from org.bukkit import Material
from org.bukkit import Sound
from org.bukkit import World
from org.bukkit.attribute import Attributable
from org.bukkit.block import Block
from org.bukkit.entity import *
from org.bukkit.entity.memory import MemoryKey
from org.bukkit.inventory import EntityEquipment
from org.bukkit.inventory import ItemStack
from org.bukkit.potion import PotionEffect
from org.bukkit.potion import PotionEffectType
from org.bukkit.projectiles import ProjectileSource
from org.bukkit.scoreboard import Scoreboard
from org.bukkit.scoreboard import Team
from org.bukkit.util import RayTraceResult
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class LivingEntity(Attributable, Damageable, ProjectileSource):
    """
    Represents a living entity, such as a monster or player
    """

    def getEyeHeight(self) -> float:
        """
        Gets the height of the living entity's eyes above its Location.

        Returns
        - height of the living entity's eyes above its location
        """
        ...


    def getEyeHeight(self, ignorePose: bool) -> float:
        """
        Gets the height of the living entity's eyes above its Location.

        Arguments
        - ignorePose: if set to True, the effects of pose changes, eg
            sneaking and gliding will be ignored

        Returns
        - height of the living entity's eyes above its location
        """
        ...


    def getEyeLocation(self) -> "Location":
        """
        Get a Location detailing the current eye position of the living entity.

        Returns
        - a location at the eyes of the living entity
        """
        ...


    def getLineOfSight(self, transparent: set["Material"], maxDistance: int) -> list["Block"]:
        """
        Gets all blocks along the living entity's line of sight.
        
        This list contains all blocks from the living entity's eye position to
        target inclusive. This method considers all blocks as 1x1x1 in size.

        Arguments
        - transparent: Set containing all transparent block Materials (set to
            null for only air)
        - maxDistance: this is the maximum distance to scan (may be limited
            by server by at least 100 blocks, no less)

        Returns
        - list containing all blocks along the living entity's line of
            sight
        """
        ...


    def getTargetBlock(self, transparent: set["Material"], maxDistance: int) -> "Block":
        """
        Gets the block that the living entity has targeted.
        
        This method considers all blocks as 1x1x1 in size. To take exact block
        collision shapes into account, see .getTargetBlockExact(int,
        FluidCollisionMode).

        Arguments
        - transparent: Set containing all transparent block Materials (set to
            null for only air)
        - maxDistance: this is the maximum distance to scan (may be limited
            by server by at least 100 blocks, no less)

        Returns
        - block that the living entity has targeted
        """
        ...


    def getLastTwoTargetBlocks(self, transparent: set["Material"], maxDistance: int) -> list["Block"]:
        """
        Gets the last two blocks along the living entity's line of sight.
        
        The target block will be the last block in the list. This method
        considers all blocks as 1x1x1 in size.

        Arguments
        - transparent: Set containing all transparent block Materials (set to
            null for only air)
        - maxDistance: this is the maximum distance to scan. This may be
            further limited by the server, but never to less than 100 blocks

        Returns
        - list containing the last 2 blocks along the living entity's
            line of sight
        """
        ...


    def getTargetBlockExact(self, maxDistance: int) -> "Block":
        """
        Gets the block that the living entity has targeted.
        
        This takes the blocks' precise collision shapes into account. Fluids are
        ignored.
        
        This may cause loading of chunks! Some implementations may impose
        artificial restrictions on the maximum distance.

        Arguments
        - maxDistance: the maximum distance to scan

        Returns
        - block that the living entity has targeted

        See
        - .getTargetBlockExact(int, org.bukkit.FluidCollisionMode)
        """
        ...


    def getTargetBlockExact(self, maxDistance: int, fluidCollisionMode: "FluidCollisionMode") -> "Block":
        """
        Gets the block that the living entity has targeted.
        
        This takes the blocks' precise collision shapes into account.
        
        This may cause loading of chunks! Some implementations may impose
        artificial restrictions on the maximum distance.

        Arguments
        - maxDistance: the maximum distance to scan
        - fluidCollisionMode: the fluid collision mode

        Returns
        - block that the living entity has targeted

        See
        - .rayTraceBlocks(double, FluidCollisionMode)
        """
        ...


    def rayTraceBlocks(self, maxDistance: float) -> "RayTraceResult":
        """
        Performs a ray trace that provides information on the targeted block.
        
        This takes the blocks' precise collision shapes into account. Fluids are
        ignored.
        
        This may cause loading of chunks! Some implementations may impose
        artificial restrictions on the maximum distance.

        Arguments
        - maxDistance: the maximum distance to scan

        Returns
        - information on the targeted block, or `null` if there
            is no targeted block in range

        See
        - .rayTraceBlocks(double, FluidCollisionMode)
        """
        ...


    def rayTraceBlocks(self, maxDistance: float, fluidCollisionMode: "FluidCollisionMode") -> "RayTraceResult":
        """
        Performs a ray trace that provides information on the targeted block.
        
        This takes the blocks' precise collision shapes into account.
        
        This may cause loading of chunks! Some implementations may impose
        artificial restrictions on the maximum distance.

        Arguments
        - maxDistance: the maximum distance to scan
        - fluidCollisionMode: the fluid collision mode

        Returns
        - information on the targeted block, or `null` if there
            is no targeted block in range

        See
        - World.rayTraceBlocks(Location, Vector, double, FluidCollisionMode)
        """
        ...


    def getRemainingAir(self) -> int:
        """
        Returns the amount of air that the living entity has remaining, in
        ticks.

        Returns
        - amount of air remaining
        """
        ...


    def setRemainingAir(self, ticks: int) -> None:
        """
        Sets the amount of air that the living entity has remaining, in ticks.

        Arguments
        - ticks: amount of air remaining
        """
        ...


    def getMaximumAir(self) -> int:
        """
        Returns the maximum amount of air the living entity can have, in ticks.

        Returns
        - maximum amount of air
        """
        ...


    def setMaximumAir(self, ticks: int) -> None:
        """
        Sets the maximum amount of air the living entity can have, in ticks.

        Arguments
        - ticks: maximum amount of air
        """
        ...


    def getItemInUse(self) -> "ItemStack":
        """
        Gets the item that the player is using (eating food, drawing back a bow,
        blocking, etc.)

        Returns
        - the item being used by the player, or null if they are not using
        an item
        """
        ...


    def getItemInUseTicks(self) -> int:
        """
        Gets the number of ticks remaining for the current item's usage.

        Returns
        - The number of ticks remaining
        """
        ...


    def setItemInUseTicks(self, ticks: int) -> None:
        """
        Sets the number of ticks that remain for the current item's usage.
        Applies to items that take time to use, like eating food, drawing a bow,
        or throwing a trident.

        Arguments
        - ticks: The number of ticks remaining
        """
        ...


    def getArrowCooldown(self) -> int:
        """
        Gets the time in ticks until the next arrow leaves the entity's body.

        Returns
        - ticks until arrow leaves
        """
        ...


    def setArrowCooldown(self, ticks: int) -> None:
        """
        Sets the time in ticks until the next arrow leaves the entity's body.

        Arguments
        - ticks: time until arrow leaves
        """
        ...


    def getArrowsInBody(self) -> int:
        """
        Gets the amount of arrows in an entity's body.

        Returns
        - amount of arrows in body
        """
        ...


    def setArrowsInBody(self, count: int) -> None:
        """
        Set the amount of arrows in the entity's body.

        Arguments
        - count: amount of arrows in entity's body
        """
        ...


    def getMaximumNoDamageTicks(self) -> int:
        """
        Returns the living entity's current maximum no damage ticks.
        
        This is the maximum duration in which the living entity will not take
        damage.

        Returns
        - maximum no damage ticks
        """
        ...


    def setMaximumNoDamageTicks(self, ticks: int) -> None:
        """
        Sets the living entity's current maximum no damage ticks.

        Arguments
        - ticks: maximum amount of no damage ticks
        """
        ...


    def getLastDamage(self) -> float:
        """
        Returns the living entity's last damage taken in the current no damage
        ticks time.
        
        Only damage higher than this amount will further damage the living
        entity.

        Returns
        - damage taken since the last no damage ticks time period
        """
        ...


    def setLastDamage(self, damage: float) -> None:
        """
        Sets the damage dealt within the current no damage ticks time period.

        Arguments
        - damage: amount of damage
        """
        ...


    def getNoDamageTicks(self) -> int:
        """
        Returns the living entity's current no damage ticks.

        Returns
        - amount of no damage ticks
        """
        ...


    def setNoDamageTicks(self, ticks: int) -> None:
        """
        Sets the living entity's current no damage ticks.

        Arguments
        - ticks: amount of no damage ticks
        """
        ...


    def getNoActionTicks(self) -> int:
        """
        Get the ticks that this entity has performed no action.
        
        The details of what "no action ticks" entails varies from entity to entity
        and cannot be specifically defined. Some examples include squid using this
        value to determine when to swim, raiders for when they are to be expelled
        from raids, or creatures (such as withers) as a requirement to be despawned.

        Returns
        - amount of no action ticks
        """
        ...


    def setNoActionTicks(self, ticks: int) -> None:
        """
        Set the ticks that this entity has performed no action.
        
        The details of what "no action ticks" entails varies from entity to entity
        and cannot be specifically defined. Some examples include squid using this
        value to determine when to swim, raiders for when they are to be expelled
        from raids, or creatures (such as withers) as a requirement to be despawned.

        Arguments
        - ticks: amount of no action ticks
        """
        ...


    def getKiller(self) -> "Player":
        """
        Gets the player identified as the killer of the living entity.
        
        May be null.

        Returns
        - killer player, or null if none found
        """
        ...


    def addPotionEffect(self, effect: "PotionEffect") -> bool:
        """
        Adds the given PotionEffect to the living entity.

        Arguments
        - effect: PotionEffect to be added

        Returns
        - whether the effect could be added
        """
        ...


    def addPotionEffect(self, effect: "PotionEffect", force: bool) -> bool:
        """
        Adds the given PotionEffect to the living entity.
        
        Only one potion effect can be present for a given PotionEffectType.

        Arguments
        - effect: PotionEffect to be added
        - force: whether conflicting effects should be removed

        Returns
        - whether the effect could be added

        Deprecated
        - no need to force since multiple effects of the same type are
        now supported.
        """
        ...


    def addPotionEffects(self, effects: Iterable["PotionEffect"]) -> bool:
        """
        Attempts to add all of the given PotionEffect to the living
        entity.

        Arguments
        - effects: the effects to add

        Returns
        - whether all of the effects could be added
        """
        ...


    def hasPotionEffect(self, type: "PotionEffectType") -> bool:
        """
        Returns whether the living entity already has an existing effect of
        the given PotionEffectType applied to it.

        Arguments
        - type: the potion type to check

        Returns
        - whether the living entity has this potion effect active on them
        """
        ...


    def getPotionEffect(self, type: "PotionEffectType") -> "PotionEffect":
        """
        Returns the active PotionEffect of the specified type.
        
        If the effect is not present on the entity then null will be returned.

        Arguments
        - type: the potion type to check

        Returns
        - the effect active on this entity, or null if not active.
        """
        ...


    def removePotionEffect(self, type: "PotionEffectType") -> None:
        """
        Removes any effects present of the given PotionEffectType.

        Arguments
        - type: the potion type to remove
        """
        ...


    def getActivePotionEffects(self) -> Iterable["PotionEffect"]:
        """
        Returns all currently active PotionEffects on the living
        entity.

        Returns
        - a collection of PotionEffects
        """
        ...


    def hasLineOfSight(self, other: "Entity") -> bool:
        """
        Checks whether the living entity has block line of sight to another.
        
        This uses the same algorithm that hostile mobs use to find the closest
        player.

        Arguments
        - other: the entity to determine line of sight to

        Returns
        - True if there is a line of sight, False if not
        """
        ...


    def getRemoveWhenFarAway(self) -> bool:
        """
        Returns if the living entity despawns when away from players or not.
        
        By default, animals are not removed while other mobs are.

        Returns
        - True if the living entity is removed when away from players
        """
        ...


    def setRemoveWhenFarAway(self, remove: bool) -> None:
        """
        Sets whether or not the living entity despawns when away from players
        or not.

        Arguments
        - remove: the removal status
        """
        ...


    def getEquipment(self) -> "EntityEquipment":
        """
        Gets the inventory with the equipment worn by the living entity.

        Returns
        - the living entity's inventory
        """
        ...


    def setCanPickupItems(self, pickup: bool) -> None:
        """
        Sets whether or not the living entity can pick up items.

        Arguments
        - pickup: whether or not the living entity can pick up items
        """
        ...


    def getCanPickupItems(self) -> bool:
        """
        Gets if the living entity can pick up items.

        Returns
        - whether or not the living entity can pick up items
        """
        ...


    def isLeashed(self) -> bool:
        """
        Returns whether the entity is currently leashed.

        Returns
        - whether the entity is leashed
        """
        ...


    def getLeashHolder(self) -> "Entity":
        """
        Gets the entity that is currently leading this entity.

        Returns
        - the entity holding the leash

        Raises
        - IllegalStateException: if not currently leashed
        """
        ...


    def setLeashHolder(self, holder: "Entity") -> bool:
        """
        Sets the leash on this entity to be held by the supplied entity.
        
        This method has no effect on EnderDragons, Withers, Players, or Bats.
        Non-living entities excluding leashes will not persist as leash
        holders.

        Arguments
        - holder: the entity to leash this entity to, or null to unleash

        Returns
        - whether the operation was successful
        """
        ...


    def isGliding(self) -> bool:
        """
        Checks to see if an entity is gliding, such as using an Elytra.

        Returns
        - True if this entity is gliding.
        """
        ...


    def setGliding(self, gliding: bool) -> None:
        """
        Makes entity start or stop gliding. This will work even if an Elytra
        is not equipped, but will be reverted by the server immediately after
        unless an event-cancelling mechanism is put in place.

        Arguments
        - gliding: True if the entity is gliding.
        """
        ...


    def isSwimming(self) -> bool:
        """
        Checks to see if an entity is swimming.

        Returns
        - True if this entity is swimming.
        """
        ...


    def setSwimming(self, swimming: bool) -> None:
        """
        Makes entity start or stop swimming.
        
        This may have unexpected results if the entity is not in water.

        Arguments
        - swimming: True if the entity is swimming.
        """
        ...


    def isRiptiding(self) -> bool:
        """
        Checks to see if an entity is currently riptiding.

        Returns
        - True if this entity is currently riptiding.
        """
        ...


    def setRiptiding(self, riptiding: bool) -> None:
        """
        Makes entity start or stop riptiding.
        
        Note: This does not damage attackable entities.

        Arguments
        - riptiding: whether the entity should start riptiding.

        See
        - HumanEntity.startRiptideAttack(int, float, ItemStack)
        """
        ...


    def isSleeping(self) -> bool:
        """
        Returns whether this entity is slumbering.

        Returns
        - slumber state
        """
        ...


    def isClimbing(self) -> bool:
        """
        Gets if the entity is climbing.

        Returns
        - if the entity is climbing
        """
        ...


    def setAI(self, ai: bool) -> None:
        """
        Sets whether an entity will have AI.
        
        The entity will be completely unable to move if it has no AI.

        Arguments
        - ai: whether the mob will have AI or not.
        """
        ...


    def hasAI(self) -> bool:
        """
        Checks whether an entity has AI.
        
        The entity will be completely unable to move if it has no AI.

        Returns
        - True if the entity has AI, otherwise False.
        """
        ...


    def attack(self, target: "Entity") -> None:
        """
        Makes this entity attack the given entity with a melee attack.
        
        Attack damage is calculated by the server from the attributes and
        equipment of this mob, and knockback is applied to `target` as
        appropriate.

        Arguments
        - target: entity to attack.
        """
        ...


    def swingMainHand(self) -> None:
        """
        Makes this entity swing their main hand.
        
        This method does nothing if this entity does not have an animation for
        swinging their main hand.
        """
        ...


    def swingOffHand(self) -> None:
        """
        Makes this entity swing their off hand.
        
        This method does nothing if this entity does not have an animation for
        swinging their off hand.
        """
        ...


    def playHurtAnimation(self, yaw: float) -> None:
        """
        Makes this entity flash red as if they were damaged.

        Arguments
        - yaw: The direction the damage is coming from in relation to the
        entity, where 0 is in front of the player, 90 is to the right, 180 is
        behind, and 270 is to the left
        """
        ...


    def setCollidable(self, collidable: bool) -> None:
        """
        Set if this entity will be subject to collisions with other entities.
        
        Exemptions to this rule can be managed with
        .getCollidableExemptions()
        
        Note that the client may predict the collision between itself and another
        entity, resulting in this flag not working for player collisions. This
        method should therefore only be used to set the collision status of
        non-player entities.
        
        To control player collisions, use Team.Option.COLLISION_RULE in
        combination with a Scoreboard and a Team.

        Arguments
        - collidable: collision status
        """
        ...


    def isCollidable(self) -> bool:
        """
        Gets if this entity is subject to collisions with other entities.
        
        Some entities might be exempted from the collidable rule of this entity.
        Use .getCollidableExemptions() to get these.
        
        Please note that this method returns only the custom collidable state,
        not whether the entity is non-collidable for other reasons such as being
        dead.
        
        Note that the client may predict the collision between itself and another
        entity, resulting in this flag not being accurate for player collisions.
        This method should therefore only be used to check the collision status
        of non-player entities.
        
        To check the collision behavior for a player, use
        Team.Option.COLLISION_RULE in combination with a
        Scoreboard and a Team.

        Returns
        - collision status
        """
        ...


    def getCollidableExemptions(self) -> set["UUID"]:
        """
        Gets a mutable set of UUIDs of the entities which are exempt from the
        entity's collidable rule and which's collision with this entity will
        behave the opposite of it.
        
        This set can be modified to add or remove exemptions.
        
        For example if collidable is True and an entity is in the exemptions set
        then it will not collide with it. Similarly if collidable is False and an
        entity is in this set then it will still collide with it.
        
        Note these exemptions are not (currently) persistent.
        
        Note that the client may predict the collision between itself and another
        entity, resulting in those exemptions not being accurate for player
        collisions. This method should therefore only be used to exempt
        non-player entities.
        
        To exempt collisions for a player, use Team.Option.COLLISION_RULE
        in combination with a Scoreboard and a Team.

        Returns
        - the collidable exemption set
        """
        ...


    def getMemory(self, memoryKey: "MemoryKey"["T"]) -> "T":
        """
        Returns the value of the memory specified.
        
        Note that the value is null when the specific entity does not have that
        value by default.
        
        Type `<T>`: the type of the return value

        Arguments
        - memoryKey: memory to access

        Returns
        - a instance of the memory section value or null if not present
        """
        ...


    def setMemory(self, memoryKey: "MemoryKey"["T"], memoryValue: "T") -> None:
        """
        Sets the value of the memory specified.
        
        Note that the value will not be persisted when the specific entity does
        not have that value by default.
        
        Type `<T>`: the type of the passed value

        Arguments
        - memoryKey: the memory to access
        - memoryValue: a typed memory value
        """
        ...


    def getHurtSound(self) -> "Sound":
        """
        Get the Sound this entity will make when damaged.

        Returns
        - the hurt sound, or null if the entity does not make any sound
        """
        ...


    def getDeathSound(self) -> "Sound":
        """
        Get the Sound this entity will make on death.

        Returns
        - the death sound, or null if the entity does not make any sound
        """
        ...


    def getFallDamageSound(self, fallHeight: int) -> "Sound":
        """
        Get the Sound this entity will make when falling from the given
        height (in blocks). The sound will often differ between either a small
        or a big fall damage sound if the height exceeds 4 blocks.

        Arguments
        - fallHeight: the fall height in blocks

        Returns
        - the fall damage sound

        See
        - .getFallDamageSoundBig()
        """
        ...


    def getFallDamageSoundSmall(self) -> "Sound":
        """
        Get the Sound this entity will make when falling from a small
        height.

        Returns
        - the fall damage sound
        """
        ...


    def getFallDamageSoundBig(self) -> "Sound":
        """
        Get the Sound this entity will make when falling from a large
        height.

        Returns
        - the fall damage sound
        """
        ...


    def getDrinkingSound(self, itemStack: "ItemStack") -> "Sound":
        """
        Get the Sound this entity will make when drinking the given
        ItemStack.

        Arguments
        - itemStack: the item stack being drank

        Returns
        - the drinking sound
        """
        ...


    def getEatingSound(self, itemStack: "ItemStack") -> "Sound":
        """
        Get the Sound this entity will make when eating the given
        ItemStack.

        Arguments
        - itemStack: the item stack being eaten

        Returns
        - the eating sound
        """
        ...


    def canBreatheUnderwater(self) -> bool:
        """
        Returns True if this entity can breathe underwater and will not take
        suffocation damage when its air supply reaches zero.

        Returns
        - `True` if the entity can breathe underwater
        """
        ...


    def getCategory(self) -> "EntityCategory":
        """
        Get the category to which this entity belongs.
        
        Categories may subject this entity to additional effects, benefits or
        debuffs.

        Returns
        - the entity category

        Deprecated
        - entity groupings are now managed by tags, not categories
        """
        ...


    def setInvisible(self, invisible: bool) -> None:
        """
        Sets whether the entity is invisible or not.

        Arguments
        - invisible: If the entity is invisible
        """
        ...


    def isInvisible(self) -> bool:
        """
        Gets whether the entity is invisible or not.

        Returns
        - Whether the entity is invisible
        """
        ...



"""
Python module generated from Java source file com.google.common.escape.ArrayBasedUnicodeEscaper

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.escape import *
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ArrayBasedUnicodeEscaper(UnicodeEscaper):
    """
    A UnicodeEscaper that uses an array to quickly look up replacement characters for a given
    code point. An additional safe range is provided that determines whether code points without
    specific replacements are to be considered safe and left unescaped or should be escaped in a
    general way.
    
    A good example of usage of this class is for HTML escaping where the replacement array
    contains information about the named HTML entities such as `&amp;` and `&quot;` while
    .escapeUnsafe is overridden to handle general escaping of the form `&.NNNNN;`.
    
    The size of the data structure used by ArrayBasedUnicodeEscaper is proportional to the
    highest valued code point that requires escaping. For example a replacement map containing the
    single character '`\``u1000`' will require approximately 16K of memory. If you need
    to create multiple escaper instances that have the same character replacement mapping consider
    using ArrayBasedEscaperMap.

    Author(s)
    - David Beaumont

    Since
    - 15.0
    """

    def escape(self, s: str) -> str:
        ...



from .DateFormat import DateFormat
from .SimpleDateFormat import SimpleDateFormat
from .ParseException import ParseException
from .ParsePosition import ParsePosition
from .DecimalFormat import DecimalFormat
from .NumberFormat import NumberFormat


"""
Python module generated from Java source file java.util.LinkedHashSet

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class LinkedHashSet(HashSet, Set, Cloneable, Serializable):

    def __init__(self, initialCapacity: int, loadFactor: float):
        """
        Constructs a new, empty linked hash set with the specified initial
        capacity and load factor.

        Arguments
        - initialCapacity: the initial capacity of the linked hash set
        - loadFactor: the load factor of the linked hash set

        Raises
        - IllegalArgumentException: if the initial capacity is less
                      than zero, or if the load factor is nonpositive
        """
        ...


    def __init__(self, initialCapacity: int):
        """
        Constructs a new, empty linked hash set with the specified initial
        capacity and the default load factor (0.75).

        Arguments
        - initialCapacity: the initial capacity of the LinkedHashSet

        Raises
        - IllegalArgumentException: if the initial capacity is less
                     than zero
        """
        ...


    def __init__(self):
        """
        Constructs a new, empty linked hash set with the default initial
        capacity (16) and load factor (0.75).
        """
        ...


    def __init__(self, c: Iterable["E"]):
        """
        Constructs a new linked hash set with the same elements as the
        specified collection.  The linked hash set is created with an initial
        capacity sufficient to hold the elements in the specified collection
        and the default load factor (0.75).

        Arguments
        - c: the collection whose elements are to be placed into
                  this set

        Raises
        - NullPointerException: if the specified collection is null
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        """
        Creates a *<a href="Spliterator.html#binding">late-binding</a>*
        and *fail-fast* `Spliterator` over the elements in this set.
        
        The `Spliterator` reports Spliterator.SIZED,
        Spliterator.DISTINCT, and `ORDERED`.  Implementations
        should document the reporting of additional characteristic values.

        Returns
        - a `Spliterator` over the elements in this set

        Since
        - 1.8

        Unknown Tags
        - The implementation creates a
        *<a href="Spliterator.html#binding">late-binding</a>* spliterator
        from the set's `Iterator`.  The spliterator inherits the
        *fail-fast* properties of the set's iterator.
        The created `Spliterator` additionally reports
        Spliterator.SUBSIZED.
        """
        ...



"""
Python module generated from Java source file com.google.common.io.TempFileCreator

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import ImmutableList
from com.google.common.io import *
from com.google.j2objc.annotations import J2ObjCIncompatible
from java.io import File
from java.io import IOException
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Method
from java.nio.file import FileSystems
from java.nio.file import Paths
from java.nio.file.attribute import AclEntry
from java.nio.file.attribute import AclEntryPermission
from java.nio.file.attribute import FileAttribute
from java.nio.file.attribute import PosixFilePermissions
from java.nio.file.attribute import UserPrincipal
from java.util import EnumSet
from typing import Any, Callable, Iterable, Tuple


class TempFileCreator:
    """
    Creates temporary files and directories whose permissions are restricted to the current user or,
    in the case of Android, the current app. If that is not possible (as is the case under the very
    old Android Ice Cream Sandwich release), then this class throws an exception instead of creating
    a file or directory that would be more accessible.
    """





"""
Python module generated from Java source file java.nio.file.attribute.AclEntry

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.nio.file.attribute import *
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class AclEntry:

    @staticmethod
    def newBuilder() -> "Builder":
        """
        Constructs a new builder. The initial value of the type and who
        components is `null`. The initial value of the permissions and
        flags components is the empty set.

        Returns
        - a new builder
        """
        ...


    @staticmethod
    def newBuilder(entry: "AclEntry") -> "Builder":
        """
        Constructs a new builder with the components of an existing ACL entry.

        Arguments
        - entry: an ACL entry

        Returns
        - a new builder
        """
        ...


    def type(self) -> "AclEntryType":
        """
        Returns the ACL entry type.

        Returns
        - the ACL entry type
        """
        ...


    def principal(self) -> "UserPrincipal":
        """
        Returns the principal component.

        Returns
        - the principal component
        """
        ...


    def permissions(self) -> set["AclEntryPermission"]:
        """
        Returns a copy of the permissions component.
        
         The returned set is a modifiable copy of the permissions.

        Returns
        - the permissions component
        """
        ...


    def flags(self) -> set["AclEntryFlag"]:
        """
        Returns a copy of the flags component.
        
         The returned set is a modifiable copy of the flags.

        Returns
        - the flags component
        """
        ...


    def equals(self, ob: "Object") -> bool:
        """
        Compares the specified object with this ACL entry for equality.
        
         If the given object is not an `AclEntry` then this method
        immediately returns `False`.
        
         For two ACL entries to be considered equals requires that they are
        both the same type, their who components are equal, their permissions
        components are equal, and their flags components are equal.
        
         This method satisfies the general contract of the java.lang.Object.equals(Object) Object.equals method. 

        Arguments
        - ob: the object to which this object is to be compared

        Returns
        - `True` if, and only if, the given object is an AclEntry that
                 is identical to this AclEntry
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash-code value for this ACL entry.
        
         This method satisfies the general contract of the Object.hashCode method.
        """
        ...


    def toString(self) -> str:
        """
        Returns the string representation of this ACL entry.

        Returns
        - the string representation of this entry
        """
        ...


    class Builder:
        """
        A builder of AclEntry objects.
        
         A `Builder` object is obtained by invoking one of the AclEntry.newBuilder newBuilder methods defined by the `AclEntry`
        class.
        
         Builder objects are mutable and are not safe for use by multiple
        concurrent threads without appropriate synchronization.

        Since
        - 1.7
        """

        def build(self) -> "AclEntry":
            """
            Constructs an AclEntry from the components of this builder.
            The type and who components are required to have been set in order
            to construct an `AclEntry`.

            Returns
            - a new ACL entry

            Raises
            - IllegalStateException: if the type or who component have not been set
            """
            ...


        def setType(self, type: "AclEntryType") -> "Builder":
            """
            Sets the type component of this builder.

            Arguments
            - type: the component type

            Returns
            - this builder
            """
            ...


        def setPrincipal(self, who: "UserPrincipal") -> "Builder":
            """
            Sets the principal component of this builder.

            Arguments
            - who: the principal component

            Returns
            - this builder
            """
            ...


        def setPermissions(self, perms: set["AclEntryPermission"]) -> "Builder":
            """
            Sets the permissions component of this builder. On return, the
            permissions component of this builder is a copy of the given set.

            Arguments
            - perms: the permissions component

            Returns
            - this builder

            Raises
            - ClassCastException: if the set contains elements that are not of type `AclEntryPermission`
            """
            ...


        def setPermissions(self, *perms: Tuple["AclEntryPermission", ...]) -> "Builder":
            """
            Sets the permissions component of this builder. On return, the
            permissions component of this builder is a copy of the permissions in
            the given array.

            Arguments
            - perms: the permissions component

            Returns
            - this builder
            """
            ...


        def setFlags(self, flags: set["AclEntryFlag"]) -> "Builder":
            """
            Sets the flags component of this builder. On return, the flags
            component of this builder is a copy of the given set.

            Arguments
            - flags: the flags component

            Returns
            - this builder

            Raises
            - ClassCastException: if the set contains elements that are not of type `AclEntryFlag`
            """
            ...


        def setFlags(self, *flags: Tuple["AclEntryFlag", ...]) -> "Builder":
            """
            Sets the flags component of this builder. On return, the flags
            component of this builder is a copy of the flags in the given
            array.

            Arguments
            - flags: the flags component

            Returns
            - this builder
            """
            ...



"""
Python module generated from Java source file com.google.common.base.FinalizableWeakReference

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import *
from java.lang.ref import ReferenceQueue
from java.lang.ref import WeakReference
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class FinalizableWeakReference(WeakReference, FinalizableReference):
    """
    Weak reference with a `finalizeReferent()` method which a background thread invokes after
    the garbage collector reclaims the referent. This is a simpler alternative to using a ReferenceQueue.

    Author(s)
    - Bob Lee

    Since
    - 2.0
    """





"""
Python module generated from Java source file com.google.common.eventbus.SubscriberExceptionContext

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.eventbus import *
from java.lang.reflect import Method
from typing import Any, Callable, Iterable, Tuple


class SubscriberExceptionContext:
    """
    Context for an exception thrown by a subscriber.

    Since
    - 16.0
    """

    def getEventBus(self) -> "EventBus":
        """
        Returns
        - The EventBus that handled the event and the subscriber. Useful for broadcasting
            a new event based on the error.
        """
        ...


    def getEvent(self) -> "Object":
        """
        Returns
        - The event object that caused the subscriber to throw.
        """
        ...


    def getSubscriber(self) -> "Object":
        """
        Returns
        - The object context that the subscriber was called on.
        """
        ...


    def getSubscriberMethod(self) -> "Method":
        """
        Returns
        - The subscribed method that threw the exception.
        """
        ...



"""
Python module generated from Java source file com.google.common.hash.HashingOutputStream

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.hash import *
from java.io import FilterOutputStream
from java.io import IOException
from java.io import OutputStream
from typing import Any, Callable, Iterable, Tuple


class HashingOutputStream(FilterOutputStream):
    """
    An OutputStream that maintains a hash of the data written to it.

    Author(s)
    - Nick Piepmeier

    Since
    - 16.0
    """

    def __init__(self, hashFunction: "HashFunction", out: "OutputStream"):
        ...


    def write(self, b: int) -> None:
        ...


    def write(self, bytes: list[int], off: int, len: int) -> None:
        ...


    def hash(self) -> "HashCode":
        """
        Returns the HashCode based on the data written to this stream. The result is
        unspecified if this method is called more than once on the same instance.
        """
        ...


    def close(self) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.entity.ZombieVillager

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import OfflinePlayer
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class ZombieVillager(Zombie):
    """
    Represents a Zombie which was once a Villager.
    """

    def setVillagerProfession(self, profession: "Villager.Profession") -> None:
        """
        Sets the villager profession of this zombie.
        """
        ...


    def getVillagerProfession(self) -> "Villager.Profession":
        """
        Returns the villager profession of this zombie.

        Returns
        - the profession or null
        """
        ...


    def getVillagerType(self) -> "Villager.Type":
        """
        Gets the current type of this villager.

        Returns
        - Current type.
        """
        ...


    def setVillagerType(self, type: "Villager.Type") -> None:
        """
        Sets the new type of this villager.

        Arguments
        - type: New type.
        """
        ...


    def isConverting(self) -> bool:
        """
        Get if this entity is in the process of converting to a Villager as a
        result of being cured.

        Returns
        - conversion status
        """
        ...


    def getConversionTime(self) -> int:
        """
        Gets the amount of ticks until this entity will be converted to a
        Villager as a result of being cured.
        
        When this reaches 0, the entity will be converted.

        Returns
        - conversion time

        Raises
        - IllegalStateException: if .isConverting() is False.
        """
        ...


    def setConversionTime(self, time: int) -> None:
        """
        Sets the amount of ticks until this entity will be converted to a
        Villager as a result of being cured.
        
        When this reaches 0, the entity will be converted. A value of less than 0
        will stop the current conversion process without converting the current
        entity.

        Arguments
        - time: new conversion time
        """
        ...


    def getConversionPlayer(self) -> "OfflinePlayer":
        """
        Gets the player who initiated the conversion.

        Returns
        - the player, or `null` if the player is unknown or the
        entity isn't converting currently
        """
        ...


    def setConversionPlayer(self, conversionPlayer: "OfflinePlayer") -> None:
        """
        Sets the player who initiated the conversion.
        
        This has no effect if this entity isn't converting currently.

        Arguments
        - conversionPlayer: the player
        """
        ...



"""
Python module generated from Java source file com.google.common.net.MediaType

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Ascii
from com.google.common.base import CharMatcher
from com.google.common.base import Joiner
from com.google.common.base.Joiner import MapJoiner
from com.google.common.base import MoreObjects
from com.google.common.base import Objects
from com.google.common.base import Optional
from com.google.common.collect import ImmutableListMultimap
from com.google.common.collect import ImmutableMultiset
from com.google.common.collect import ImmutableSet
from com.google.common.collect import Maps
from com.google.common.collect import Multimap
from com.google.common.collect import Multimaps
from com.google.common.net import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import Immutable
from com.google.errorprone.annotations.concurrent import LazyInit
from java.nio.charset import Charset
from java.nio.charset import IllegalCharsetNameException
from java.nio.charset import UnsupportedCharsetException
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MediaType:
    """
    Represents an <a href="http://en.wikipedia.org/wiki/Internet_media_type">Internet Media Type</a>
    (also known as a MIME Type or Content Type). This class also supports the concept of media ranges
    <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.1">defined by HTTP/1.1</a>.
    As such, the `*` character is treated as a wildcard and is used to represent any acceptable
    type or subtype value. A media type may not have wildcard type with a declared subtype. The
    `*` character has no special meaning as part of a parameter. All values for type, subtype,
    parameter attributes or parameter values must be valid according to RFCs <a
    href="https://tools.ietf.org/html/rfc2045">2045</a> and <a
    href="https://tools.ietf.org/html/rfc2046">2046</a>.
    
    All portions of the media type that are case-insensitive (type, subtype, parameter attributes)
    are normalized to lowercase. The value of the `charset` parameter is normalized to
    lowercase, but all others are left as-is.
    
    Note that this specifically does <strong>not</strong> represent the value of the MIME `Content-Type` header and as such has no support for header-specific considerations such as line
    folding and comments.
    
    For media types that take a charset the predefined constants default to UTF-8 and have a
    "_UTF_8" suffix. To get a version without a character set, use .withoutParameters.

    Author(s)
    - Gregory Kick

    Since
    - 12.0
    """

    ANY_TYPE = createConstant(WILDCARD, WILDCARD)
    ANY_TEXT_TYPE = createConstant(TEXT_TYPE, WILDCARD)
    ANY_IMAGE_TYPE = createConstant(IMAGE_TYPE, WILDCARD)
    ANY_AUDIO_TYPE = createConstant(AUDIO_TYPE, WILDCARD)
    ANY_VIDEO_TYPE = createConstant(VIDEO_TYPE, WILDCARD)
    ANY_APPLICATION_TYPE = createConstant(APPLICATION_TYPE, WILDCARD)
    ANY_FONT_TYPE = createConstant(FONT_TYPE, WILDCARD)
    """
    Wildcard matching any "font" top-level media type.

    Since
    - 30.0
    """
    CACHE_MANIFEST_UTF_8 = createConstantUtf8(TEXT_TYPE, "cache-manifest")
    CSS_UTF_8 = createConstantUtf8(TEXT_TYPE, "css")
    CSV_UTF_8 = createConstantUtf8(TEXT_TYPE, "csv")
    HTML_UTF_8 = createConstantUtf8(TEXT_TYPE, "html")
    I_CALENDAR_UTF_8 = createConstantUtf8(TEXT_TYPE, "calendar")
    MD_UTF_8 = createConstantUtf8(TEXT_TYPE, "markdown")
    """
    As described in <a href="https://www.rfc-editor.org/rfc/rfc7763.html">RFC 7763</a>, this
    constant (`text/markdown`) is used for Markdown documents.

    Since
    - 33.3.0
    """
    PLAIN_TEXT_UTF_8 = createConstantUtf8(TEXT_TYPE, "plain")
    TEXT_JAVASCRIPT_UTF_8 = createConstantUtf8(TEXT_TYPE, "javascript")
    """
    <a href="http://www.rfc-editor.org/rfc/rfc4329.txt">RFC 4329</a> declares .JAVASCRIPT_UTF_8 application/javascript to be the correct media type for JavaScript, but this
    may be necessary in certain situations for compatibility.
    """
    TSV_UTF_8 = createConstantUtf8(TEXT_TYPE, "tab-separated-values")
    """
    <a href="http://www.iana.org/assignments/media-types/text/tab-separated-values">Tab separated
    values</a>.

    Since
    - 15.0
    """
    VCARD_UTF_8 = createConstantUtf8(TEXT_TYPE, "vcard")
    WML_UTF_8 = createConstantUtf8(TEXT_TYPE, "vnd.wap.wml")
    """
    UTF-8 encoded <a href="https://en.wikipedia.org/wiki/Wireless_Markup_Language">Wireless Markup
    Language</a>.

    Since
    - 13.0
    """
    XML_UTF_8 = createConstantUtf8(TEXT_TYPE, "xml")
    """
    As described in <a href="http://www.ietf.org/rfc/rfc3023.txt">RFC 3023</a>, this constant
    (`text/xml`) is used for XML documents that are "readable by casual users." .APPLICATION_XML_UTF_8 is provided for documents that are intended for applications.
    """
    VTT_UTF_8 = createConstantUtf8(TEXT_TYPE, "vtt")
    """
    As described in <a href="https://w3c.github.io/webvtt/#iana-text-vtt">the VTT spec</a>, this is
    used for Web Video Text Tracks (WebVTT) files, used with the HTML5 track element.

    Since
    - 20.0
    """
    BMP = createConstant(IMAGE_TYPE, "bmp")
    """
    <a href="https://en.wikipedia.org/wiki/BMP_file_format">Bitmap file format</a> (`bmp`
    files).

    Since
    - 13.0
    """
    CRW = createConstant(IMAGE_TYPE, "x-canon-crw")
    """
    The <a href="https://en.wikipedia.org/wiki/Camera_Image_File_Format">Canon Image File
    Format</a> (`crw` files), a widely-used "raw image" format for cameras. It is found in
    `/etc/mime.types`, e.g. in <a href=
    "http://anonscm.debian.org/gitweb/?p=collab-maint/mime-support.git;a=blob;f=mime.types;hb=HEAD"
    >Debian 3.48-1</a>.

    Since
    - 15.0
    """
    GIF = createConstant(IMAGE_TYPE, "gif")
    ICO = createConstant(IMAGE_TYPE, "vnd.microsoft.icon")
    JPEG = createConstant(IMAGE_TYPE, "jpeg")
    PNG = createConstant(IMAGE_TYPE, "png")
    PSD = createConstant(IMAGE_TYPE, "vnd.adobe.photoshop")
    """
    The Photoshop File Format (`psd` files) as defined by <a
    href="http://www.iana.org/assignments/media-types/image/vnd.adobe.photoshop">IANA</a>, and
    found in `/etc/mime.types`, e.g. <a
    href="http://svn.apache.org/repos/asf/httpd/httpd/branches/1.3.x/conf/mime.types"></a> of the
    Apache <a href="http://httpd.apache.org/">HTTPD project</a>; for the specification, see <a
    href="http://www.adobe.com/devnet-apps/photoshop/fileformatashtml/PhotoshopFileFormats.htm">
    Adobe Photoshop Document Format</a> and <a
    href="http://en.wikipedia.org/wiki/Adobe_Photoshop#File_format">Wikipedia</a>; this is the
    regular output/input of Photoshop (which can also export to various image formats; note that
    files with extension "PSB" are in a distinct but related format).
    
    This is a more recent replacement for the older, experimental type `x-photoshop`: <a
    href="http://tools.ietf.org/html/rfc2046#section-6">RFC-2046.6</a>.

    Since
    - 15.0
    """
    SVG_UTF_8 = createConstantUtf8(IMAGE_TYPE, "svg+xml")
    TIFF = createConstant(IMAGE_TYPE, "tiff")
    WEBP = createConstant(IMAGE_TYPE, "webp")
    """
    <a href="https://en.wikipedia.org/wiki/WebP">WebP image format</a>.

    Since
    - 13.0
    """
    HEIF = createConstant(IMAGE_TYPE, "heif")
    """
    <a href="https://www.iana.org/assignments/media-types/image/heif">HEIF image format</a>.

    Since
    - 28.1
    """
    JP2K = createConstant(IMAGE_TYPE, "jp2")
    """
    <a href="https://tools.ietf.org/html/rfc3745">JP2K image format</a>.

    Since
    - 28.1
    """
    MP4_AUDIO = createConstant(AUDIO_TYPE, "mp4")
    MPEG_AUDIO = createConstant(AUDIO_TYPE, "mpeg")
    OGG_AUDIO = createConstant(AUDIO_TYPE, "ogg")
    WEBM_AUDIO = createConstant(AUDIO_TYPE, "webm")
    L16_AUDIO = createConstant(AUDIO_TYPE, "l16")
    """
    L16 audio, as defined by <a href="https://tools.ietf.org/html/rfc2586">RFC 2586</a>.

    Since
    - 24.1
    """
    L24_AUDIO = createConstant(AUDIO_TYPE, "l24")
    """
    L24 audio, as defined by <a href="https://tools.ietf.org/html/rfc3190">RFC 3190</a>.

    Since
    - 20.0
    """
    BASIC_AUDIO = createConstant(AUDIO_TYPE, "basic")
    """
    Basic Audio, as defined by <a href="http://tools.ietf.org/html/rfc2046#section-4.3">RFC
    2046</a>.

    Since
    - 20.0
    """
    AAC_AUDIO = createConstant(AUDIO_TYPE, "aac")
    """
    Advanced Audio Coding. For more information, see <a
    href="https://en.wikipedia.org/wiki/Advanced_Audio_Coding">Advanced Audio Coding</a>.

    Since
    - 20.0
    """
    VORBIS_AUDIO = createConstant(AUDIO_TYPE, "vorbis")
    """
    Vorbis Audio, as defined by <a href="http://tools.ietf.org/html/rfc5215">RFC 5215</a>.

    Since
    - 20.0
    """
    WMA_AUDIO = createConstant(AUDIO_TYPE, "x-ms-wma")
    """
    Windows Media Audio. For more information, see <a
    href="https://msdn.microsoft.com/en-us/library/windows/desktop/dd562994(v=vs.85).aspx">file
    name extensions for Windows Media metafiles</a>.

    Since
    - 20.0
    """
    WAX_AUDIO = createConstant(AUDIO_TYPE, "x-ms-wax")
    """
    Windows Media metafiles. For more information, see <a
    href="https://msdn.microsoft.com/en-us/library/windows/desktop/dd562994(v=vs.85).aspx">file
    name extensions for Windows Media metafiles</a>.

    Since
    - 20.0
    """
    VND_REAL_AUDIO = createConstant(AUDIO_TYPE, "vnd.rn-realaudio")
    """
    Real Audio. For more information, see <a
    href="http://service.real.com/help/faq/rp8/configrp8win.html">this link</a>.

    Since
    - 20.0
    """
    VND_WAVE_AUDIO = createConstant(AUDIO_TYPE, "vnd.wave")
    """
    WAVE format, as defined by <a href="https://tools.ietf.org/html/rfc2361">RFC 2361</a>.

    Since
    - 20.0
    """
    MP4_VIDEO = createConstant(VIDEO_TYPE, "mp4")
    MPEG_VIDEO = createConstant(VIDEO_TYPE, "mpeg")
    OGG_VIDEO = createConstant(VIDEO_TYPE, "ogg")
    QUICKTIME = createConstant(VIDEO_TYPE, "quicktime")
    WEBM_VIDEO = createConstant(VIDEO_TYPE, "webm")
    WMV = createConstant(VIDEO_TYPE, "x-ms-wmv")
    FLV_VIDEO = createConstant(VIDEO_TYPE, "x-flv")
    """
    Flash video. For more information, see <a href=
    "http://help.adobe.com/en_US/ActionScript/3.0_ProgrammingAS3/WS5b3ccc516d4fbf351e63e3d118a9b90204-7d48.html"
    >this link</a>.

    Since
    - 20.0
    """
    THREE_GPP_VIDEO = createConstant(VIDEO_TYPE, "3gpp")
    """
    The 3GP multimedia container format. For more information, see <a
    href="ftp://www.3gpp.org/tsg_sa/TSG_SA/TSGS_23/Docs/PDF/SP-040065.pdf#page=10">3GPP TS
    26.244</a>.

    Since
    - 20.0
    """
    THREE_GPP2_VIDEO = createConstant(VIDEO_TYPE, "3gpp2")
    """
    The 3G2 multimedia container format. For more information, see <a
    href="http://www.3gpp2.org/Public_html/specs/C.S0050-B_v1.0_070521.pdf#page=16">3GPP2
    C.S0050-B</a>.

    Since
    - 20.0
    """
    APPLICATION_XML_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "xml")
    """
    As described in <a href="http://www.ietf.org/rfc/rfc3023.txt">RFC 3023</a>, this constant
    (`application/xml`) is used for XML documents that are "unreadable by casual users."
    .XML_UTF_8 is provided for documents that may be read by users.

    Since
    - 14.0
    """
    ATOM_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "atom+xml")
    BZIP2 = createConstant(APPLICATION_TYPE, "x-bzip2")
    DART_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "dart")
    """
    Files in the <a href="https://www.dartlang.org/articles/embedding-in-html/">dart</a>
    programming language.

    Since
    - 19.0
    """
    APPLE_PASSBOOK = createConstant(APPLICATION_TYPE, "vnd.apple.pkpass")
    """
    <a
    href="https://developer.apple.com/library/archive/documentation/UserExperience/Conceptual/PassKit_PG/DistributingPasses.html">Apple
    Passbook</a>.

    Since
    - 19.0
    """
    EOT = createConstant(APPLICATION_TYPE, "vnd.ms-fontobject")
    """
    <a href="http://en.wikipedia.org/wiki/Embedded_OpenType">Embedded OpenType</a> fonts. This is
    <a href="http://www.iana.org/assignments/media-types/application/vnd.ms-fontobject">registered
    </a> with the IANA.

    Since
    - 17.0
    """
    EPUB = createConstant(APPLICATION_TYPE, "epub+zip")
    """
    As described in the <a href="http://idpf.org/epub">International Digital Publishing Forum</a>
    EPUB is the distribution and interchange format standard for digital publications and
    documents. This media type is defined in the <a
    href="http://www.idpf.org/epub/30/spec/epub30-ocf.html">EPUB Open Container Format</a>
    specification.

    Since
    - 15.0
    """
    FORM_DATA = createConstant(APPLICATION_TYPE, "x-www-form-urlencoded")
    KEY_ARCHIVE = createConstant(APPLICATION_TYPE, "pkcs12")
    """
    As described in <a href="https://www.rsa.com/rsalabs/node.asp?id=2138">PKCS #12: Personal
    Information Exchange Syntax Standard</a>, PKCS #12 defines an archive file format for storing
    many cryptography objects as a single file.

    Since
    - 15.0
    """
    APPLICATION_BINARY = createConstant(APPLICATION_TYPE, "binary")
    """
    This is a non-standard media type, but is commonly used in serving hosted binary files as it is
    <a href="http://code.google.com/p/browsersec/wiki/Part2#Survey_of_content_sniffing_behaviors">
    known not to trigger content sniffing in current browsers</a>. It *should not* be used in
    other situations as it is not specified by any RFC and does not appear in the <a
    href="http://www.iana.org/assignments/media-types">/IANA MIME Media Types</a> list. Consider
    .OCTET_STREAM for binary data that is not being served to a browser.

    Since
    - 14.0
    """
    GEO_JSON = createConstant(APPLICATION_TYPE, "geo+json")
    """
    Media type for the <a href="https://tools.ietf.org/html/rfc7946">GeoJSON Format</a>, a
    geospatial data interchange format based on JSON.

    Since
    - 28.0
    """
    GZIP = createConstant(APPLICATION_TYPE, "x-gzip")
    HAL_JSON = createConstant(APPLICATION_TYPE, "hal+json")
    """
    <a href="https://tools.ietf.org/html/draft-kelly-json-hal-08#section-3">JSON Hypertext
    Application Language (HAL) documents</a>.

    Since
    - 26.0
    """
    JAVASCRIPT_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "javascript")
    """
    <a href="http://www.rfc-editor.org/rfc/rfc4329.txt">RFC 4329</a> declares this to be the
    correct media type for JavaScript, but .TEXT_JAVASCRIPT_UTF_8 text/javascript may be
    necessary in certain situations for compatibility.
    """
    JOSE = createConstant(APPLICATION_TYPE, "jose")
    """
    For <a href="https://tools.ietf.org/html/rfc7515">JWS or JWE objects using the Compact
    Serialization</a>.

    Since
    - 27.1
    """
    JOSE_JSON = createConstant(APPLICATION_TYPE, "jose+json")
    """
    For <a href="https://tools.ietf.org/html/rfc7515">JWS or JWE objects using the JSON
    Serialization</a>.

    Since
    - 27.1
    """
    JSON_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "json")
    JWT = createConstant(APPLICATION_TYPE, "jwt")
    """
    For <a href="https://tools.ietf.org/html/7519">JWT objects using the compact Serialization</a>.

    Since
    - 32.0.0
    """
    MANIFEST_JSON_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "manifest+json")
    """
    The <a href="http://www.w3.org/TR/appmanifest/">Manifest for a web application</a>.

    Since
    - 19.0
    """
    KML = createConstant(APPLICATION_TYPE, "vnd.google-earth.kml+xml")
    """
    <a href="http://www.opengeospatial.org/standards/kml/">OGC KML (Keyhole Markup Language)</a>.
    """
    KMZ = createConstant(APPLICATION_TYPE, "vnd.google-earth.kmz")
    """
    <a href="http://www.opengeospatial.org/standards/kml/">OGC KML (Keyhole Markup Language)</a>,
    compressed using the ZIP format into KMZ archives.
    """
    MBOX = createConstant(APPLICATION_TYPE, "mbox")
    """
    The <a href="https://tools.ietf.org/html/rfc4155">mbox database format</a>.

    Since
    - 13.0
    """
    APPLE_MOBILE_CONFIG = createConstant(APPLICATION_TYPE, "x-apple-aspen-config")
    """
    <a
    href="https://developer.apple.com/library/archive/documentation/NetworkingInternet/Conceptual/iPhoneOTAConfiguration/profile-service/profile-service.html">Apple
    over-the-air mobile configuration profiles</a>.

    Since
    - 18.0
    """
    MICROSOFT_EXCEL = createConstant(APPLICATION_TYPE, "vnd.ms-excel")
    """
    <a
    href="https://learn.microsoft.com/en-us/archive/blogs/vsofficedeveloper/office-2007-file-format-mime-types-for-http-content-streaming-2">Microsoft
    Excel</a> spreadsheets.
    """
    MICROSOFT_OUTLOOK = createConstant(APPLICATION_TYPE, "vnd.ms-outlook")
    """
    <a href="https://www.loc.gov/preservation/digital/formats/fdd/fdd000379.shtml">Microsoft
    Outlook</a> items.

    Since
    - 27.1
    """
    MICROSOFT_POWERPOINT = createConstant(APPLICATION_TYPE, "vnd.ms-powerpoint")
    """
    <a
    href="https://learn.microsoft.com/en-us/archive/blogs/vsofficedeveloper/office-2007-file-format-mime-types-for-http-content-streaming-2">Microsoft
    Powerpoint</a> presentations.
    """
    MICROSOFT_WORD = createConstant(APPLICATION_TYPE, "msword")
    """
    <a
    href="https://learn.microsoft.com/en-us/archive/blogs/vsofficedeveloper/office-2007-file-format-mime-types-for-http-content-streaming-2">Microsoft
    Word</a> documents.
    """
    MEDIA_PRESENTATION_DESCRIPTION = createConstant(APPLICATION_TYPE, "dash+xml")
    """
    Media type for <a
    href="https://en.wikipedia.org/wiki/Dynamic_Adaptive_Streaming_over_HTTP">Dynamic Adaptive
    Streaming over HTTP (DASH)</a>. This is <a
    href="https://www.iana.org/assignments/media-types/application/dash+xml">registered</a> with
    the IANA.

    Since
    - 28.2
    """
    WASM_APPLICATION = createConstant(APPLICATION_TYPE, "wasm")
    """
    WASM applications. For more information see <a href="https://webassembly.org/">the Web Assembly
    overview</a>.

    Since
    - 27.0
    """
    NACL_APPLICATION = createConstant(APPLICATION_TYPE, "x-nacl")
    """
    NaCl applications. For more information see <a
    href="https://developer.chrome.com/native-client/devguide/coding/application-structure">the
    Developer Guide for Native Client Application Structure</a>.

    Since
    - 20.0
    """
    NACL_PORTABLE_APPLICATION = createConstant(APPLICATION_TYPE, "x-pnacl")
    """
    NaCl portable applications. For more information see <a
    href="https://developer.chrome.com/native-client/devguide/coding/application-structure">the
    Developer Guide for Native Client Application Structure</a>.

    Since
    - 20.0
    """
    OCTET_STREAM = createConstant(APPLICATION_TYPE, "octet-stream")
    OGG_CONTAINER = createConstant(APPLICATION_TYPE, "ogg")
    OOXML_DOCUMENT = createConstant(APPLICATION_TYPE, "vnd.openxmlformats-officedocument.wordprocessingml.document")
    OOXML_PRESENTATION = createConstant(APPLICATION_TYPE, "vnd.openxmlformats-officedocument.presentationml.presentation")
    OOXML_SHEET = createConstant(APPLICATION_TYPE, "vnd.openxmlformats-officedocument.spreadsheetml.sheet")
    OPENDOCUMENT_GRAPHICS = createConstant(APPLICATION_TYPE, "vnd.oasis.opendocument.graphics")
    OPENDOCUMENT_PRESENTATION = createConstant(APPLICATION_TYPE, "vnd.oasis.opendocument.presentation")
    OPENDOCUMENT_SPREADSHEET = createConstant(APPLICATION_TYPE, "vnd.oasis.opendocument.spreadsheet")
    OPENDOCUMENT_TEXT = createConstant(APPLICATION_TYPE, "vnd.oasis.opendocument.text")
    OPENSEARCH_DESCRIPTION_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "opensearchdescription+xml")
    """
    <a href="https://tools.ietf.org/id/draft-ellermann-opensearch-01.html">OpenSearch</a>
    Description files are XML files that describe how a website can be used as a search engine by
    consumers (e.g. web browsers).

    Since
    - 28.2
    """
    PDF = createConstant(APPLICATION_TYPE, "pdf")
    POSTSCRIPT = createConstant(APPLICATION_TYPE, "postscript")
    PROTOBUF = createConstant(APPLICATION_TYPE, "protobuf")
    """
    <a href="http://tools.ietf.org/html/draft-rfernando-protocol-buffers-00">Protocol buffers</a>

    Since
    - 15.0
    """
    RDF_XML_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "rdf+xml")
    """
    <a href="https://en.wikipedia.org/wiki/RDF/XML">RDF/XML</a> documents, which are XML
    serializations of <a
    href="https://en.wikipedia.org/wiki/Resource_Description_Framework">Resource Description
    Framework</a> graphs.

    Since
    - 14.0
    """
    RTF_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "rtf")
    SFNT = createConstant(APPLICATION_TYPE, "font-sfnt")
    """
    <a href="https://tools.ietf.org/html/rfc8081">RFC 8081</a> declares .FONT_SFNT
    font/sfnt to be the correct media type for SFNT, but this may be necessary in certain
    situations for compatibility.

    Since
    - 17.0
    """
    SHOCKWAVE_FLASH = createConstant(APPLICATION_TYPE, "x-shockwave-flash")
    SKETCHUP = createConstant(APPLICATION_TYPE, "vnd.sketchup.skp")
    """
    `skp` files produced by the 3D Modeling software <a
    href="https://www.sketchup.com/">SketchUp</a>

    Since
    - 13.0
    """
    SOAP_XML_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "soap+xml")
    """
    As described in <a href="http://www.ietf.org/rfc/rfc3902.txt">RFC 3902</a>, this constant
    (`application/soap+xml`) is used to identify SOAP 1.2 message envelopes that have been
    serialized with XML 1.0.
    
    For SOAP 1.1 messages, see `XML_UTF_8` per <a
    href="http://www.w3.org/TR/2000/NOTE-SOAP-20000508/">W3C Note on Simple Object Access Protocol
    (SOAP) 1.1</a>

    Since
    - 20.0
    """
    TAR = createConstant(APPLICATION_TYPE, "x-tar")
    WOFF = createConstant(APPLICATION_TYPE, "font-woff")
    """
    <a href="https://tools.ietf.org/html/rfc8081">RFC 8081</a> declares .FONT_WOFF
    font/woff to be the correct media type for WOFF, but this may be necessary in certain
    situations for compatibility.

    Since
    - 17.0
    """
    WOFF2 = createConstant(APPLICATION_TYPE, "font-woff2")
    """
    <a href="https://tools.ietf.org/html/rfc8081">RFC 8081</a> declares .FONT_WOFF2
    font/woff2 to be the correct media type for WOFF2, but this may be necessary in certain
    situations for compatibility.

    Since
    - 20.0
    """
    XHTML_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "xhtml+xml")
    XRD_UTF_8 = createConstantUtf8(APPLICATION_TYPE, "xrd+xml")
    """
    Extensible Resource Descriptors. This is not yet registered with the IANA, but it is specified
    by OASIS in the <a href="http://docs.oasis-open.org/xri/xrd/v1.0/cd02/xrd-1.0-cd02.html">XRD
    definition</a> and implemented in projects such as <a
    href="http://code.google.com/p/webfinger/">WebFinger</a>.

    Since
    - 14.0
    """
    ZIP = createConstant(APPLICATION_TYPE, "zip")
    FONT_COLLECTION = createConstant(FONT_TYPE, "collection")
    """
    A collection of font outlines as defined by <a href="https://tools.ietf.org/html/rfc8081">RFC
    8081</a>.

    Since
    - 30.0
    """
    FONT_OTF = createConstant(FONT_TYPE, "otf")
    """
    <a href="https://en.wikipedia.org/wiki/OpenType">Open Type Font Format</a> (OTF) as defined by
    <a href="https://tools.ietf.org/html/rfc8081">RFC 8081</a>.

    Since
    - 30.0
    """
    FONT_SFNT = createConstant(FONT_TYPE, "sfnt")
    """
    <a href="https://en.wikipedia.org/wiki/SFNT">Spline or Scalable Font Format</a> (SFNT). <a
    href="https://tools.ietf.org/html/rfc8081">RFC 8081</a> declares this to be the correct media
    type for SFNT, but .SFNT application/font-sfnt may be necessary in certain situations
    for compatibility.

    Since
    - 30.0
    """
    FONT_TTF = createConstant(FONT_TYPE, "ttf")
    """
    <a href="https://en.wikipedia.org/wiki/TrueType">True Type Font Format</a> (TTF) as defined by
    <a href="https://tools.ietf.org/html/rfc8081">RFC 8081</a>.

    Since
    - 30.0
    """
    FONT_WOFF = createConstant(FONT_TYPE, "woff")
    """
    <a href="http://en.wikipedia.org/wiki/Web_Open_Font_Format">Web Open Font Format</a> (WOFF). <a
    href="https://tools.ietf.org/html/rfc8081">RFC 8081</a> declares this to be the correct media
    type for SFNT, but .WOFF application/font-woff may be necessary in certain situations
    for compatibility.

    Since
    - 30.0
    """
    FONT_WOFF2 = createConstant(FONT_TYPE, "woff2")
    """
    <a href="http://en.wikipedia.org/wiki/Web_Open_Font_Format">Web Open Font Format</a> (WOFF2).
    <a href="https://tools.ietf.org/html/rfc8081">RFC 8081</a> declares this to be the correct
    media type for SFNT, but .WOFF2 application/font-woff2 may be necessary in certain
    situations for compatibility.

    Since
    - 30.0
    """


    def type(self) -> str:
        """
        Returns the top-level media type. For example, `"text"` in `"text/plain"`.
        """
        ...


    def subtype(self) -> str:
        """
        Returns the media subtype. For example, `"plain"` in `"text/plain"`.
        """
        ...


    def parameters(self) -> "ImmutableListMultimap"[str, str]:
        """
        Returns a multimap containing the parameters of this media type.
        """
        ...


    def charset(self) -> "Optional"["Charset"]:
        """
        Returns an optional charset for the value of the charset parameter if it is specified.

        Raises
        - IllegalStateException: if multiple charset values have been set for this media type
        - IllegalCharsetNameException: if a charset value is present, but illegal
        - UnsupportedCharsetException: if a charset value is present, but no support is available
            in this instance of the Java virtual machine
        """
        ...


    def withoutParameters(self) -> "MediaType":
        """
        Returns a new instance with the same type and subtype as this instance, but without any
        parameters.
        """
        ...


    def withParameters(self, parameters: "Multimap"[str, str]) -> "MediaType":
        """
        *Replaces* all parameters with the given parameters.

        Raises
        - IllegalArgumentException: if any parameter or value is invalid
        """
        ...


    def withParameters(self, attribute: str, values: Iterable[str]) -> "MediaType":
        """
        *Replaces* all parameters with the given attribute with parameters using the given
        values. If there are no values, any existing parameters with the given attribute are removed.

        Raises
        - IllegalArgumentException: if either `attribute` or `values` is invalid

        Since
        - 24.0
        """
        ...


    def withParameter(self, attribute: str, value: str) -> "MediaType":
        """
        *Replaces* all parameters with the given attribute with a single parameter with the
        given value. If multiple parameters with the same attributes are necessary use .withParameters(String, Iterable). Prefer .withCharset for setting the `charset`
        parameter when using a Charset object.

        Raises
        - IllegalArgumentException: if either `attribute` or `value` is invalid
        """
        ...


    def withCharset(self, charset: "Charset") -> "MediaType":
        """
        Returns a new instance with the same type and subtype as this instance, with the `charset` parameter set to the Charset.name name of the given charset. Only one `charset` parameter will be present on the new instance regardless of the number set on this
        one.
        
        If a charset must be specified that is not supported on this JVM (and thus is not
        representable as a Charset instance), use .withParameter.
        """
        ...


    def hasWildcard(self) -> bool:
        """
        Returns True if either the type or subtype is the wildcard.
        """
        ...


    def is(self, mediaTypeRange: "MediaType") -> bool:
        """
        Returns `True` if this instance falls within the range (as defined by <a
        href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html">the HTTP Accept header</a>) given
        by the argument according to three criteria:
        
        <ol>
          - The type of the argument is the wildcard or equal to the type of this instance.
          - The subtype of the argument is the wildcard or equal to the subtype of this instance.
          - All of the parameters present in the argument are present in this instance.
        </ol>
        
        For example:
        
        ````PLAIN_TEXT_UTF_8.is(PLAIN_TEXT_UTF_8) // True
        PLAIN_TEXT_UTF_8.is(HTML_UTF_8) // False
        PLAIN_TEXT_UTF_8.is(ANY_TYPE) // True
        PLAIN_TEXT_UTF_8.is(ANY_TEXT_TYPE) // True
        PLAIN_TEXT_UTF_8.is(ANY_IMAGE_TYPE) // False
        PLAIN_TEXT_UTF_8.is(ANY_TEXT_TYPE.withCharset(UTF_8)) // True
        PLAIN_TEXT_UTF_8.withoutParameters().is(ANY_TEXT_TYPE.withCharset(UTF_8)) // False
        PLAIN_TEXT_UTF_8.is(ANY_TEXT_TYPE.withCharset(UTF_16)) // False````
        
        Note that while it is possible to have the same parameter declared multiple times within a
        media type this method does not consider the number of occurrences of a parameter. For example,
        `"text/plain; charset=UTF-8"` satisfies `"text/plain; charset=UTF-8;
        charset=UTF-8"`.
        """
        ...


    @staticmethod
    def create(type: str, subtype: str) -> "MediaType":
        """
        Creates a new media type with the given type and subtype.

        Raises
        - IllegalArgumentException: if type or subtype is invalid or if a wildcard is used for the
            type, but not the subtype.
        """
        ...


    @staticmethod
    def parse(input: str) -> "MediaType":
        """
        Parses a media type from its string representation.

        Raises
        - IllegalArgumentException: if the input is not parsable
        """
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        """
        Returns the string representation of this media type in the format described in <a
        href="http://www.ietf.org/rfc/rfc2045.txt">RFC 2045</a>.
        """
        ...



"""
Python module generated from Java source file java.io.ObjectInput

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class ObjectInput(DataInput, AutoCloseable):
    """
    ObjectInput extends the DataInput interface to include the reading of
    objects. DataInput includes methods for the input of primitive types,
    ObjectInput extends that interface to include objects, arrays, and Strings.

    See
    - java.io.ObjectInputStream

    Since
    - 1.1
    """

    def readObject(self) -> "Object":
        """
        Read and return an object. The class that implements this interface
        defines where the object is "read" from.

        Returns
        - the object read from the stream

        Raises
        - java.lang.ClassNotFoundException: If the class of a serialized
                   object cannot be found.
        - IOException: If any of the usual Input/Output
                   related exceptions occur.
        """
        ...


    def read(self) -> int:
        """
        Reads a byte of data. This method will block if no input is
        available.

        Returns
        - the byte read, or -1 if the end of the
                 stream is reached.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def read(self, b: list[int]) -> int:
        """
        Reads into an array of bytes.  This method will
        block until some input is available.

        Arguments
        - b: the buffer into which the data is read

        Returns
        - the actual number of bytes read, -1 is
                 returned when the end of the stream is reached.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        """
        Reads into an array of bytes.  This method will
        block until some input is available.

        Arguments
        - b: the buffer into which the data is read
        - off: the start offset of the data
        - len: the maximum number of bytes read

        Returns
        - the actual number of bytes read, -1 is
                 returned when the end of the stream is reached.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def skip(self, n: int) -> int:
        """
        Skips n bytes of input.

        Arguments
        - n: the number of bytes to be skipped

        Returns
        - the actual number of bytes skipped.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def available(self) -> int:
        """
        Returns the number of bytes that can be read
        without blocking.

        Returns
        - the number of available bytes.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...


    def close(self) -> None:
        """
        Closes the input stream. Must be called
        to release any resources associated with
        the stream.

        Raises
        - IOException: If an I/O error has occurred.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ExplicitOrdering

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.io import Serializable
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ExplicitOrdering(Ordering, Serializable):
    """
    An ordering that compares objects according to a given order.
    """

    def compare(self, left: "T", right: "T") -> int:
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.SculkShrieker

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Waterlogged
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class SculkShrieker(Waterlogged):
    """
    'can_summon' indicates whether the sculk shrieker can summon the warden.
    
    'shrieking' indicated whether the sculk shrieker is shrieking or not.
    """

    def isCanSummon(self) -> bool:
        """
        Gets the value of the 'can_summon' property.

        Returns
        - the 'can_summon' value
        """
        ...


    def setCanSummon(self, can_summon: bool) -> None:
        """
        Sets the value of the 'can_summon' property.

        Arguments
        - can_summon: the new 'can_summon' value
        """
        ...


    def isShrieking(self) -> bool:
        """
        Gets the value of the 'shrieking' property.

        Returns
        - the 'shrieking' value
        """
        ...


    def setShrieking(self, shrieking: bool) -> None:
        """
        Sets the value of the 'shrieking' property.

        Arguments
        - shrieking: the new 'shrieking' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.trim.TrimPattern

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Keyed
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit import Translatable
from org.bukkit.inventory.meta.trim import *
from org.bukkit.registry import RegistryAware
from typing import Any, Callable, Iterable, Tuple


class TrimPattern(Keyed, Translatable, RegistryAware):
    """
    Represents a pattern that may be used in an ArmorTrim.
    """

    SENTRY = getTrimPattern("sentry")
    """
    Material.SENTRY_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    DUNE = getTrimPattern("dune")
    """
    Material.DUNE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    COAST = getTrimPattern("coast")
    """
    Material.COAST_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    WILD = getTrimPattern("wild")
    """
    Material.WILD_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    WARD = getTrimPattern("ward")
    """
    Material.WARD_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    EYE = getTrimPattern("eye")
    """
    Material.EYE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    VEX = getTrimPattern("vex")
    """
    Material.VEX_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    TIDE = getTrimPattern("tide")
    """
    Material.TIDE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SNOUT = getTrimPattern("snout")
    """
    Material.SNOUT_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    RIB = getTrimPattern("rib")
    """
    Material.RIB_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SPIRE = getTrimPattern("spire")
    """
    Material.SPIRE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    WAYFINDER = getTrimPattern("wayfinder")
    """
    Material.WAYFINDER_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SHAPER = getTrimPattern("shaper")
    """
    Material.SHAPER_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    SILENCE = getTrimPattern("silence")
    """
    Material.SILENCE_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    RAISER = getTrimPattern("raiser")
    """
    Material.RAISER_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    HOST = getTrimPattern("host")
    """
    Material.HOST_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    FLOW = getTrimPattern("flow")
    """
    Material.FLOW_ARMOR_TRIM_SMITHING_TEMPLATE.
    """
    BOLT = getTrimPattern("bolt")
    """
    Material.BOLT_ARMOR_TRIM_SMITHING_TEMPLATE.
    """


    @staticmethod
    def getTrimPattern(key: str) -> "TrimPattern":
        ...


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...



"""
Python module generated from Java source file org.bukkit.advancement.AdvancementRequirement

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.advancement import *
from typing import Any, Callable, Iterable, Tuple


class AdvancementRequirement:

    def getRequiredCriteria(self) -> list[str]:
        """
        Get all required criteria.

        Returns
        - the list of required criteria for this requirement.
        """
        ...


    def isStrict(self) -> bool:
        """
        Check if the requirement is strict.

        Returns
        - True if requirement list contains one criteria, False if
        multiple.
        """
        ...



"""
Python module generated from Java source file com.google.common.hash.AbstractByteHasher

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.hash import *
from com.google.common.primitives import Chars
from com.google.common.primitives import Ints
from com.google.common.primitives import Longs
from com.google.common.primitives import Shorts
from com.google.errorprone.annotations import CanIgnoreReturnValue
from typing import Any, Callable, Iterable, Tuple


class AbstractByteHasher(AbstractHasher):
    """
    Abstract Hasher that handles converting primitives to bytes using a scratch `ByteBuffer` and streams all bytes to a sink to compute the hash.

    Author(s)
    - Colin Decker
    """

    def putByte(self, b: int) -> "Hasher":
        ...


    def putBytes(self, bytes: list[int]) -> "Hasher":
        ...


    def putBytes(self, bytes: list[int], off: int, len: int) -> "Hasher":
        ...


    def putBytes(self, bytes: "ByteBuffer") -> "Hasher":
        ...


    def putShort(self, s: int) -> "Hasher":
        ...


    def putInt(self, i: int) -> "Hasher":
        ...


    def putLong(self, l: int) -> "Hasher":
        ...


    def putChar(self, c: str) -> "Hasher":
        ...



"""
Python module generated from Java source file org.bukkit.SoundGroup

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class SoundGroup:
    """
    Represents a group of sounds for blocks that are played when various actions
    happen (ie stepping, breaking, hitting, etc).
    """

    def getVolume(self) -> float:
        """
        Get the volume these sounds are played at.
        
        Note that this volume does not always represent the actual volume
        received by the client.

        Returns
        - volume
        """
        ...


    def getPitch(self) -> float:
        """
        Gets the pitch these sounds are played at.
        
        Note that this pitch does not always represent the actual pitch received
        by the client.

        Returns
        - pitch
        """
        ...


    def getBreakSound(self) -> "Sound":
        """
        Gets the corresponding breaking sound for this group.

        Returns
        - the break sound
        """
        ...


    def getStepSound(self) -> "Sound":
        """
        Gets the corresponding step sound for this group.

        Returns
        - the step sound
        """
        ...


    def getPlaceSound(self) -> "Sound":
        """
        Gets the corresponding place sound for this group.

        Returns
        - the place sound
        """
        ...


    def getHitSound(self) -> "Sound":
        """
        Gets the corresponding hit sound for this group.

        Returns
        - the hit sound
        """
        ...


    def getFallSound(self) -> "Sound":
        """
        Gets the corresponding fall sound for this group.

        Returns
        - the fall sound
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.hanging.HangingEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Hanging
from org.bukkit.event import Event
from org.bukkit.event.hanging import *
from typing import Any, Callable, Iterable, Tuple


class HangingEvent(Event):
    """
    Represents a hanging entity-related event.
    """

    def getEntity(self) -> "Hanging":
        """
        Gets the hanging entity involved in this event.

        Returns
        - the hanging entity
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.Repairable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class Repairable(ItemMeta):
    """
    Represents an item that can be repaired at an anvil.
    """

    def hasRepairCost(self) -> bool:
        """
        Checks to see if this has a repair penalty

        Returns
        - True if this has a repair penalty
        """
        ...


    def getRepairCost(self) -> int:
        """
        Gets the repair penalty

        Returns
        - the repair penalty
        """
        ...


    def setRepairCost(self, cost: int) -> None:
        """
        Sets the repair penalty

        Arguments
        - cost: repair penalty
        """
        ...


    def clone(self) -> "Repairable":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.AsyncPlayerChatEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import IllegalFormatException
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class AsyncPlayerChatEvent(PlayerEvent, Cancellable):
    """
    This event will sometimes fire synchronously, depending on how it was
    triggered.
    
    The constructor provides a boolean to indicate if the event was fired
    synchronously or asynchronously. When asynchronous, this event can be
    called from any thread, sans the main thread, and has limited access to the
    API.
    
    If a player is the direct cause of this event by an incoming packet, this
    event will be asynchronous. If a plugin triggers this event by compelling a
    player to chat, this event will be synchronous.
    
    Care should be taken to check .isAsynchronous() and treat the event
    appropriately.
    """

    def __init__(self, async: bool, who: "Player", message: str, players: set["Player"]):
        """
        Arguments
        - async: This changes the event to a synchronous state.
        - who: the chat sender
        - message: the message sent
        - players: the players to receive the message. This may be a lazy
            or unmodifiable collection.
        """
        ...


    def getMessage(self) -> str:
        """
        Gets the message that the player is attempting to send. This message
        will be used with .getFormat().

        Returns
        - Message the player is attempting to send
        """
        ...


    def setMessage(self, message: str) -> None:
        """
        Sets the message that the player will send. This message will be used
        with .getFormat().

        Arguments
        - message: New message that the player will send
        """
        ...


    def getFormat(self) -> str:
        """
        Gets the format to use to display this chat message.
        
        When this event finishes execution, the first format parameter is the
        Player.getDisplayName() and the second parameter is .getMessage()

        Returns
        - String.format(String, Object...) compatible format
            string
        """
        ...


    def setFormat(self, format: str) -> None:
        """
        Sets the format to use to display this chat message.
        
        When this event finishes execution, the first format parameter is the
        Player.getDisplayName() and the second parameter is .getMessage()

        Arguments
        - format: String.format(String, Object...) compatible
            format string

        Raises
        - IllegalFormatException: if the underlying API throws the
            exception
        - NullPointerException: if format is null

        See
        - String.format(String, Object...)
        """
        ...


    def getRecipients(self) -> set["Player"]:
        """
        Gets a set of recipients that this chat message will be displayed to.
        
        The set returned is not guaranteed to be mutable and may auto-populate
        on access. Any listener accessing the returned set should be aware that
        it may reduce performance for a lazy set implementation.
        
        Listeners should be aware that modifying the list may throw UnsupportedOperationException if the event caller provides an
        unmodifiable set.

        Returns
        - All Players who will see this chat message
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.plugin.messaging.StandardMessenger

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ImmutableSet
from com.google.common.collect.ImmutableSet import Builder
from java.util import Locale
from org.bukkit.entity import Player
from org.bukkit.plugin import Plugin
from org.bukkit.plugin.messaging import *
from typing import Any, Callable, Iterable, Tuple


class StandardMessenger(Messenger):
    """
    Standard implementation to Messenger
    """

    def isReservedChannel(self, channel: str) -> bool:
        ...


    def registerOutgoingPluginChannel(self, plugin: "Plugin", channel: str) -> None:
        ...


    def unregisterOutgoingPluginChannel(self, plugin: "Plugin", channel: str) -> None:
        ...


    def unregisterOutgoingPluginChannel(self, plugin: "Plugin") -> None:
        ...


    def registerIncomingPluginChannel(self, plugin: "Plugin", channel: str, listener: "PluginMessageListener") -> "PluginMessageListenerRegistration":
        ...


    def unregisterIncomingPluginChannel(self, plugin: "Plugin", channel: str, listener: "PluginMessageListener") -> None:
        ...


    def unregisterIncomingPluginChannel(self, plugin: "Plugin", channel: str) -> None:
        ...


    def unregisterIncomingPluginChannel(self, plugin: "Plugin") -> None:
        ...


    def getOutgoingChannels(self) -> set[str]:
        ...


    def getOutgoingChannels(self, plugin: "Plugin") -> set[str]:
        ...


    def getIncomingChannels(self) -> set[str]:
        ...


    def getIncomingChannels(self, plugin: "Plugin") -> set[str]:
        ...


    def getIncomingChannelRegistrations(self, plugin: "Plugin") -> set["PluginMessageListenerRegistration"]:
        ...


    def getIncomingChannelRegistrations(self, channel: str) -> set["PluginMessageListenerRegistration"]:
        ...


    def getIncomingChannelRegistrations(self, plugin: "Plugin", channel: str) -> set["PluginMessageListenerRegistration"]:
        ...


    def isRegistrationValid(self, registration: "PluginMessageListenerRegistration") -> bool:
        ...


    def isIncomingChannelRegistered(self, plugin: "Plugin", channel: str) -> bool:
        ...


    def isOutgoingChannelRegistered(self, plugin: "Plugin", channel: str) -> bool:
        ...


    def dispatchIncomingMessage(self, source: "Player", channel: str, message: list[int]) -> None:
        ...


    @staticmethod
    def validateChannel(channel: str) -> None:
        """
        Validates a Plugin Channel name.

        Arguments
        - channel: Channel name to validate.

        Deprecated
        - not an API method
        """
        ...


    @staticmethod
    def validateAndCorrectChannel(channel: str) -> str:
        """
        Validates and corrects a Plugin Channel name. Method is not reentrant / idempotent.

        Arguments
        - channel: Channel name to validate.

        Returns
        - corrected channel name

        Deprecated
        - not an API method
        """
        ...


    @staticmethod
    def validatePluginMessage(messenger: "Messenger", source: "Plugin", channel: str, message: list[int]) -> None:
        """
        Validates the input of a Plugin Message, ensuring the arguments are all
        valid.

        Arguments
        - messenger: Messenger to use for validation.
        - source: Source plugin of the Message.
        - channel: Plugin Channel to send the message by.
        - message: Raw message payload to send.

        Raises
        - IllegalArgumentException: Thrown if the source plugin is
            disabled.
        - IllegalArgumentException: Thrown if source, channel or message
            is null.
        - MessageTooLargeException: Thrown if the message is too big.
        - ChannelNameTooLongException: Thrown if the channel name is too
            long.
        - ChannelNotRegisteredException: Thrown if the channel is not
            registered for this plugin.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.world.WorldEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import World
from org.bukkit.event import Event
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class WorldEvent(Event):
    """
    Represents events within a world
    """

    def __init__(self, world: "World"):
        ...


    def __init__(self, world: "World", isAsync: bool):
        ...


    def getWorld(self) -> "World":
        """
        Gets the world primarily involved with this event

        Returns
        - World which caused this event
        """
        ...



"""
Python module generated from Java source file java.security.Key

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.security import *
from typing import Any, Callable, Iterable, Tuple


class Key(Serializable):

    serialVersionUID = 6603384152749567654L
    """
    The class fingerprint that is set to indicate
    serialization compatibility with a previous
    version of the class.

    Deprecated
    - A `serialVersionUID` field in an interface is
    ineffectual. Do not use; no replacement.
    """


    def getAlgorithm(self) -> str:
        """
        Returns the standard algorithm name for this key. For
        example, "DSA" would indicate that this key is a DSA key.
        See the key related sections (KeyFactory, KeyGenerator,
        KeyPairGenerator, and SecretKeyFactory) in the <a href=
        "/../specs/security/standard-names.html">
        Java Security Standard Algorithm Names Specification</a>
        for information about standard key algorithm names.

        Returns
        - the name of the algorithm associated with this key.
        """
        ...


    def getFormat(self) -> str:
        """
        Returns the name of the primary encoding format of this key,
        or null if this key does not support encoding.
        The primary encoding format is
        named in terms of the appropriate ASN.1 data format, if an
        ASN.1 specification for this key exists.
        For example, the name of the ASN.1 data format for public
        keys is <I>SubjectPublicKeyInfo</I>, as
        defined by the X.509 standard; in this case, the returned format is
        `"X.509"`. Similarly,
        the name of the ASN.1 data format for private keys is
        <I>PrivateKeyInfo</I>,
        as defined by the PKCS #8 standard; in this case, the returned format is
        `"PKCS.8"`.

        Returns
        - the primary encoding format of the key.
        """
        ...


    def getEncoded(self) -> list[int]:
        """
        Returns the key in its primary encoding format, or null
        if this key does not support encoding.

        Returns
        - the encoded key, or null if the key does not support
        encoding.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.Yaml

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import InputStream
from java.io import Reader
from java.io import StringReader
from java.io import StringWriter
from java.io import Writer
from java.util import Iterator
from java.util import NoSuchElementException
from java.util.regex import Pattern
from org.yaml.snakeyaml import *
from org.yaml.snakeyaml.DumperOptions import FlowStyle
from org.yaml.snakeyaml.composer import Composer
from org.yaml.snakeyaml.constructor import BaseConstructor
from org.yaml.snakeyaml.constructor import Constructor
from org.yaml.snakeyaml.emitter import Emitable
from org.yaml.snakeyaml.emitter import Emitter
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.events import Event
from org.yaml.snakeyaml.introspector import BeanAccess
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.nodes import Tag
from org.yaml.snakeyaml.parser import Parser
from org.yaml.snakeyaml.parser import ParserImpl
from org.yaml.snakeyaml.reader import StreamReader
from org.yaml.snakeyaml.reader import UnicodeReader
from org.yaml.snakeyaml.representer import Representer
from org.yaml.snakeyaml.resolver import Resolver
from org.yaml.snakeyaml.serializer import Serializer
from typing import Any, Callable, Iterable, Tuple


class Yaml:
    """
    Public YAML interface. This class is not thread-safe. Which means that all the methods of the
    same instance can be called only by one thread. It is better to create an instance for every YAML
    stream.
    """

    def __init__(self):
        """
        Create Yaml instance.
        """
        ...


    def __init__(self, dumperOptions: "DumperOptions"):
        """
        Create Yaml instance.

        Arguments
        - dumperOptions: DumperOptions to configure outgoing objects
        """
        ...


    def __init__(self, loadingConfig: "LoaderOptions"):
        """
        Create Yaml instance.

        Arguments
        - loadingConfig: LoadingConfig to control load behavior
        """
        ...


    def __init__(self, representer: "Representer"):
        """
        Create Yaml instance.

        Arguments
        - representer: Representer to emit outgoing objects
        """
        ...


    def __init__(self, constructor: "BaseConstructor"):
        """
        Create Yaml instance.

        Arguments
        - constructor: BaseConstructor to construct incoming documents
        """
        ...


    def __init__(self, constructor: "BaseConstructor", representer: "Representer"):
        """
        Create Yaml instance.

        Arguments
        - constructor: BaseConstructor to construct incoming documents
        - representer: Representer to emit outgoing objects
        """
        ...


    def __init__(self, representer: "Representer", dumperOptions: "DumperOptions"):
        """
        Create Yaml instance. It is safe to create a few instances and use them in different Threads.

        Arguments
        - representer: Representer to emit outgoing objects
        - dumperOptions: DumperOptions to configure outgoing objects
        """
        ...


    def __init__(self, constructor: "BaseConstructor", representer: "Representer", dumperOptions: "DumperOptions"):
        """
        Create Yaml instance. It is safe to create a few instances and use them in different Threads.

        Arguments
        - constructor: BaseConstructor to construct incoming documents. Its LoaderOptions will be
               used everywhere
        - representer: Representer to emit outgoing objects
        - dumperOptions: DumperOptions to configure outgoing objects
        """
        ...


    def __init__(self, constructor: "BaseConstructor", representer: "Representer", dumperOptions: "DumperOptions", loadingConfig: "LoaderOptions"):
        """
        Create Yaml instance. It is safe to create a few instances and use them in different Threads.

        Arguments
        - constructor: BaseConstructor to construct incoming documents
        - representer: Representer to emit outgoing objects
        - dumperOptions: DumperOptions to configure outgoing objects
        - loadingConfig: LoadingConfig to control load behavior
        """
        ...


    def __init__(self, constructor: "BaseConstructor", representer: "Representer", dumperOptions: "DumperOptions", resolver: "Resolver"):
        """
        Create Yaml instance. It is safe to create a few instances and use them in different Threads.

        Arguments
        - constructor: BaseConstructor to construct incoming documents
        - representer: Representer to emit outgoing objects
        - dumperOptions: DumperOptions to configure outgoing objects
        - resolver: Resolver to detect implicit type
        """
        ...


    def __init__(self, constructor: "BaseConstructor", representer: "Representer", dumperOptions: "DumperOptions", loadingConfig: "LoaderOptions", resolver: "Resolver"):
        """
        Create Yaml instance. It is safe to create a few instances and use them in different Threads.

        Arguments
        - constructor: BaseConstructor to construct incoming documents
        - representer: Representer to emit outgoing objects
        - dumperOptions: DumperOptions to configure outgoing objects
        - loadingConfig: LoadingConfig to control load behavior
        - resolver: Resolver to detect implicit type
        """
        ...


    def dump(self, data: "Object") -> str:
        """
        Serialize a Java object into a YAML String.

        Arguments
        - data: Java object to be Serialized to YAML

        Returns
        - YAML String
        """
        ...


    def represent(self, data: "Object") -> "Node":
        """
        Produce the corresponding representation tree for a given Object.

        Arguments
        - data: instance to build the representation tree for

        Returns
        - representation tree

        See
        - <a href="http://yaml.org/spec/1.1/.id859333">Figure 3.1. Processing Overview</a>
        """
        ...


    def dumpAll(self, data: Iterator["Object"]) -> str:
        """
        Serialize a sequence of Java objects into a YAML String.

        Arguments
        - data: Iterator with Objects

        Returns
        - YAML String with all the objects in proper sequence
        """
        ...


    def dump(self, data: "Object", output: "Writer") -> None:
        """
        Serialize a Java object into a YAML stream.

        Arguments
        - data: Java object to be serialized to YAML
        - output: stream to write to
        """
        ...


    def dumpAll(self, data: Iterator["Object"], output: "Writer") -> None:
        """
        Serialize a sequence of Java objects into a YAML stream.

        Arguments
        - data: Iterator with Objects
        - output: stream to write to
        """
        ...


    def dumpAs(self, data: "Object", rootTag: "Tag", flowStyle: "FlowStyle") -> str:
        """
        
        Serialize a Java object into a YAML string. Override the default root tag with
        `rootTag`.
        
        
        
        This method is similar to `Yaml.dump(data)` except that the root tag for the whole
        document is replaced with the given tag. This has two main uses.
        
        
        
        First, if the root tag is replaced with a standard YAML tag, such as `Tag.MAP`, then
        the object will be dumped as a map. The root tag will appear as `!!map`, or blank
        (implicit !!map).
        
        
        
        Second, if the root tag is replaced by a different custom tag, then the document appears to be
        a different type when loaded. For example, if an instance of MyClass is dumped with the tag
        !!YourClass, then it will be handled as an instance of YourClass when loaded.

        Arguments
        - data: Java object to be serialized to YAML
        - rootTag: the tag for the whole YAML document. The tag should be Tag.MAP for a JavaBean to
               make the tag disappear (to use implicit tag !!map). If `null` is provided
               then the standard tag with the full class name is used.
        - flowStyle: flow style for the whole document. See Chapter 10. Collection Styles
               http://yaml.org/spec/1.1/#id930798. If `null` is provided then the flow style
               from DumperOptions is used.

        Returns
        - YAML String
        """
        ...


    def dumpAsMap(self, data: "Object") -> str:
        """
        
        Serialize a Java object into a YAML string. Override the default root tag with
        `Tag.MAP`.
        
        
        This method is similar to `Yaml.dump(data)` except that the root tag for the whole
        document is replaced with `Tag.MAP` tag (implicit !!map).
        
        
        Block Mapping is used as the collection style. See 10.2.2. Block Mappings
        (http://yaml.org/spec/1.1/#id934537)

        Arguments
        - data: Java object to be serialized to YAML

        Returns
        - YAML String
        """
        ...


    def serialize(self, node: "Node", output: "Writer") -> None:
        """
        Serialize (dump) a YAML node into a YAML stream.

        Arguments
        - node: YAML node to be serialized to YAML
        - output: stream to write to
        """
        ...


    def serialize(self, data: "Node") -> list["Event"]:
        """
        Serialize the representation tree into Events.

        Arguments
        - data: representation tree

        Returns
        - Event list

        See
        - <a href="http://yaml.org/spec/1.1/.id859333">Processing Overview</a>
        """
        ...


    def load(self, yaml: str) -> "T":
        """
        Parse the only YAML document in a String and produce the corresponding Java object. (Because
        the encoding in known BOM is not respected.)
        
        Type `<T>`: the class of the instance to be created

        Arguments
        - yaml: YAML data to load from (BOM must not be present)

        Returns
        - parsed object
        """
        ...


    def load(self, io: "InputStream") -> "T":
        """
        Parse the only YAML document in a stream and produce the corresponding Java object.
        
        Type `<T>`: the class of the instance to be created

        Arguments
        - io: data to load from (BOM is respected to detect encoding and removed from the data)

        Returns
        - parsed object
        """
        ...


    def load(self, io: "Reader") -> "T":
        """
        Parse the only YAML document in a stream and produce the corresponding Java object.
        
        Type `<T>`: the class of the instance to be created

        Arguments
        - io: data to load from (BOM must not be present)

        Returns
        - parsed object
        """
        ...


    def loadAs(self, io: "Reader", type: type["T"]) -> "T":
        """
        Parse the only YAML document in a stream and produce the corresponding Java object.
        
        Type `<T>`: Class is defined by the second argument

        Arguments
        - io: data to load from (BOM must not be present)
        - type: Class of the object to be created

        Returns
        - parsed object
        """
        ...


    def loadAs(self, yaml: str, type: type["T"]) -> "T":
        """
        Parse the only YAML document in a String and produce the corresponding Java object. (Because
        the encoding in known BOM is not respected.)
        
        Type `<T>`: Class is defined by the second argument

        Arguments
        - yaml: YAML data to load from (BOM must not be present)
        - type: Class of the object to be created

        Returns
        - parsed object
        """
        ...


    def loadAs(self, input: "InputStream", type: type["T"]) -> "T":
        """
        Parse the only YAML document in a stream and produce the corresponding Java object.
        
        Type `<T>`: Class is defined by the second argument

        Arguments
        - input: data to load from (BOM is respected to detect encoding and removed from the data)
        - type: Class of the object to be created

        Returns
        - parsed object
        """
        ...


    def loadAll(self, yaml: "Reader") -> Iterable["Object"]:
        """
        Parse all YAML documents in the Reader and produce corresponding Java objects. The documents
        are parsed only when the iterator is invoked.

        Arguments
        - yaml: YAML data to load from (BOM must not be present)

        Returns
        - an Iterable over the parsed Java objects in this String in proper sequence
        """
        ...


    def loadAll(self, yaml: str) -> Iterable["Object"]:
        """
        Parse all YAML documents in a String and produce corresponding Java objects. (Because the
        encoding in known BOM is not respected.) The documents are parsed only when the iterator is
        invoked.

        Arguments
        - yaml: YAML data to load from (BOM must not be present)

        Returns
        - an Iterable over the parsed Java objects in this String in proper sequence
        """
        ...


    def loadAll(self, yaml: "InputStream") -> Iterable["Object"]:
        """
        Parse all YAML documents in a stream and produce corresponding Java objects. The documents are
        parsed only when the iterator is invoked.

        Arguments
        - yaml: YAML data to load from (BOM is respected to detect encoding and removed from the
               data)

        Returns
        - an Iterable over the parsed Java objects in this stream in proper sequence
        """
        ...


    def compose(self, yaml: "Reader") -> "Node":
        """
        Parse the first YAML document in a stream and produce the corresponding representation tree.
        (This is the opposite of the represent() method)

        Arguments
        - yaml: YAML document

        Returns
        - parsed root Node for the specified YAML document

        See
        - <a href="http://yaml.org/spec/1.1/.id859333">Figure 3.1. Processing Overview</a>
        """
        ...


    def composeAll(self, yaml: "Reader") -> Iterable["Node"]:
        """
        Parse all YAML documents in a stream and produce corresponding representation trees.

        Arguments
        - yaml: stream of YAML documents

        Returns
        - parsed root Nodes for all the specified YAML documents

        See
        - <a href="http://yaml.org/spec/1.1/.id859333">Processing Overview</a>
        """
        ...


    def addImplicitResolver(self, tag: "Tag", regexp: "Pattern", first: str) -> None:
        """
        Add an implicit scalar detector. If an implicit scalar value matches the given regexp, the
        corresponding tag is assigned to the scalar.

        Arguments
        - tag: tag to assign to the node
        - regexp: regular expression to match against
        - first: a sequence of possible initial characters or null (which means any).
        """
        ...


    def addImplicitResolver(self, tag: "Tag", regexp: "Pattern", first: str, limit: int) -> None:
        """
        Add an implicit scalar detector. If an implicit scalar value matches the given regexp, the
        corresponding tag is assigned to the scalar.

        Arguments
        - tag: tag to assign to the node
        - regexp: regular expression to match against
        - first: a sequence of possible initial characters or null (which means any).
        - limit: the max length of the value which may match the regular expression
        """
        ...


    def toString(self) -> str:
        ...


    def getName(self) -> str:
        """
        Get a meaningful name. It simplifies debugging in a multi-threaded environment. If nothing is
        set explicitly the address of the instance is returned.

        Returns
        - human readable name
        """
        ...


    def setName(self, name: str) -> None:
        """
        Set a meaningful name to be shown in toString()

        Arguments
        - name: human readable name
        """
        ...


    def parse(self, yaml: "Reader") -> Iterable["Event"]:
        """
        Parse a YAML stream and produce parsing events.

        Arguments
        - yaml: YAML document(s)

        Returns
        - parsed events

        See
        - <a href="http://yaml.org/spec/1.1/.id859333">Processing Overview</a>
        """
        ...


    def setBeanAccess(self, beanAccess: "BeanAccess") -> None:
        ...


    def addTypeDescription(self, td: "TypeDescription") -> None:
        ...



"""
Python module generated from Java source file com.google.common.cache.RemovalListeners

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.cache import *
from java.util.concurrent import Executor
from typing import Any, Callable, Iterable, Tuple


class RemovalListeners:
    """
    A collection of common removal listeners.

    Author(s)
    - Charles Fry

    Since
    - 10.0
    """

    @staticmethod
    def asynchronous(listener: "RemovalListener"["K", "V"], executor: "Executor") -> "RemovalListener"["K", "V"]:
        """
        Returns a `RemovalListener` which processes all eviction notifications using `executor`.

        Arguments
        - listener: the backing listener
        - executor: the executor with which removal notifications are asynchronously executed
        """
        ...



"""
Python module generated from Java source file java.lang.reflect.GenericArrayType

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import *
from typing import Any, Callable, Iterable, Tuple


class GenericArrayType(Type):
    """
    `GenericArrayType` represents an array type whose component
    type is either a parameterized type or a type variable.

    Since
    - 1.5

    Unknown Tags
    - 10.1 Array Types
    """

    def getGenericComponentType(self) -> "Type":
        """
        Returns a `Type` object representing the component type
        of this array. This method creates the component type of the
        array.  See the declaration of java.lang.reflect.ParameterizedType ParameterizedType for the
        semantics of the creation process for parameterized types and
        see java.lang.reflect.TypeVariable TypeVariable for the
        creation process for type variables.

        Returns
        - a `Type` object representing the component type
            of this array

        Raises
        - TypeNotPresentException: if the underlying array type's component
            type refers to a non-existent class or interface declaration
        - MalformedParameterizedTypeException: if  the
            underlying array type's component type refers to a
            parameterized type that cannot be instantiated for any reason
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.tokens.DirectiveToken

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.tokens import *
from typing import Any, Callable, Iterable, Tuple


class DirectiveToken(Token):
    """
    Directive Token
    
    Type `<T>`: it is either Integer for the YAML directive or String for the TAG directive
    """

    def __init__(self, name: str, value: list["T"], startMark: "Mark", endMark: "Mark"):
        """
        Create

        Arguments
        - name: - directive name
        - value: - directive value
        - startMark: - start
        - endMark: - end
        """
        ...


    def getName(self) -> str:
        """
        getter

        Returns
        - name
        """
        ...


    def getValue(self) -> list["T"]:
        """
        getter

        Returns
        - value
        """
        ...


    def getTokenId(self) -> "Token.ID":
        """
        getter

        Returns
        - its identity
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingList

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from java.util import ListIterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingList(ForwardingCollection, List):
    """
    A list which forwards all its method calls to another list. Subclasses should override one or
    more methods to modify the behavior of the backing list as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    This class does not implement java.util.RandomAccess. If the delegate supports random
    access, the `ForwardingList` subclass should implement the `RandomAccess` interface.
    
    **Warning:** The methods of `ForwardingList` forward **indiscriminately** to the
    methods of the delegate. For example, overriding .add alone **will not** change the
    behavior of .addAll, which can lead to unexpected behavior. In this case, you should
    override `addAll` as well, either providing your own implementation, or delegating to the
    provided `standardAddAll` method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingList`.
    
    The `standard` methods and any collection views they return are not guaranteed to be
    thread-safe, even when all of the methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    def add(self, index: int, element: "E") -> None:
        ...


    def addAll(self, index: int, elements: Iterable["E"]) -> bool:
        ...


    def get(self, index: int) -> "E":
        ...


    def indexOf(self, element: "Object") -> int:
        ...


    def lastIndexOf(self, element: "Object") -> int:
        ...


    def listIterator(self) -> "ListIterator"["E"]:
        ...


    def listIterator(self, index: int) -> "ListIterator"["E"]:
        ...


    def remove(self, index: int) -> "E":
        ...


    def set(self, index: int, element: "E") -> "E":
        ...


    def subList(self, fromIndex: int, toIndex: int) -> list["E"]:
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...
